@@ -105,7 +105,7 @@ EOF
 #
 # Define constants and default values for variables
 #
-RELEASE=3.0
+RELEASE=3.0.1
 PYFVER=pyformex-$RELEASE
 PYTHON=python3
 ECHO=
