@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2021 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 2.6  (Mon Aug 23 15:13:50 CEST 2021)
+##  This file is part of pyFormex 3.0  (Mon Nov 22 14:32:59 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -175,7 +175,7 @@ DATA_FILES = listTree(
 
 # scripts to install extra programs
 EXTRA_FILES = listTree(
-    'pyformex/extra',listdirs=True,
+    'pyformex/extra', listdirs=False,
     includedir=[
         'calpy',
         'dxfparser',
@@ -220,7 +220,7 @@ DIST_FILES = [
     'README.rst',
     'LICENSE',
     'Description',
-    'Makefile',
+    'install.sh',
     'apt_install_deps',
     'ReleaseNotes',
     'manifest.py',
@@ -252,10 +252,6 @@ DIST_FILES = [
                            ],
              includefile=['[_A-Z].*\.py$','apps.cat','README']
              ) + \
-    listTree('pyformex/vtk_light',
-             includedir=['util'],
-             includefile=['README','.*\.py$'],
-             ) + \
     DATA_FILES + \
     DOC_FILES + \
     EXTRA_FILES
