@@ -40,11 +40,12 @@ from pyformex import elements
 from pyformex.simple import rectangle
 from pyformex.plugins.fe import FEModel
 from pyformex.plugins.properties import PropertyDB, ElemSection
-# from pyformex.plugins.fe_abq import *
+from pyformex.plugins.fe_abq import Step, AbqData, Result, Output
 from pyformex.plugins.fe_post import FeResult
 from pyformex.plugins import postproc_menu
 from pyformex.plugins import geometry_menu
 from pyformex.plugins import isopar
+from pyformex.plugins import PluginMenu
 
 # global data
 
@@ -330,7 +331,7 @@ def setMaterial():
         if K:
             for k in range(len(parts)):
                 e = getPickedElems(K, k) + model.celems[k]
-                eltype = abq_eltype[model.elems[k].eltype.name()]
+                eltype = abq_eltype[model.elems[k].eltype.lname]
                 if res['reduced_integration']:
                     eltype += 'R'
                 print(k, e)
@@ -533,12 +534,12 @@ def createCalixInput():
     secprops = PDB.getProp(kind='e', attr=['section'])
     print(secprops)
     # need E, nu, thickness, rho
-    mats = array([[sec.young_modulus,
+    mats = np.array([[sec.young_modulus,
                    sec.poisson_ratio,
                    sec.thickness,
                    sec.density,
                    ] for sec in secprops])
-    matnr = zeros(nelems, dtype=int32)
+    matnr = np.zeros(nelems, dtype=int32)
     for i, mat in enumerate(secprops):  # proces in same order as above!
         matnr[mat.set] = i+1
     print(matnr)
@@ -568,7 +569,7 @@ use for cmdlog cmdlog
 ;--------
 nodes coord %s 1
 """ % nnodes)
-    fil.write('\n'.join(["%5i%10.2f%10.2f"%(i, x[0], x[1]) for i, x in zip(arange(nnodes)+1, model.coords)]))
+    fil.write('\n'.join(["%5i%10.2f%10.2f"%(i, x[0], x[1]) for i, x in zip(np.arange(nnodes)+1, model.coords)]))
     fil.write('\n\n')
     # Boundary conditions
     fil.write(""";-----------------------------------------
@@ -580,9 +581,9 @@ plane
     for p in PDB.getProp(kind='n', attr=['bound']):
         bnd = "%5i" + "%5i"*2 % (p.bound[0], p.bound[1])
         if p.set is None:
-            nod = arange(model.nnodes)
+            nod = np.arange(model.nnodes)
         else:
-            nod = array(p.set)
+            nod = np.array(p.set)
         fil.write('\n'.join([bnd % i for i in nod+1]))
         fil.write('\n')
     fil.write('\n')
@@ -615,7 +616,7 @@ array mat    %s 4
 ;----------
 elements elems-%s matnr-%s  %s %s 1
 """ % (igrp, igrp, nplex, nelems))
-        fil.write('\n'.join(["%5i"*(nplex+2) % tuple([i, 1]+e.tolist()) for i, e in zip(arange(nelems)+1, grp+1)]))
+        fil.write('\n'.join(["%5i"*(nplex+2) % tuple([i, 1]+e.tolist()) for i, e in zip(np.arange(nelems)+1, grp+1)]))
         fil.write('\n\n')
         fil.write("""plane plane-%s coord bcon elems-%s matnr-%s 2 2
 """ % (igrp, igrp, igrp))
@@ -633,7 +634,7 @@ loads f bcon 1
         for p in cloads:
             loadcase = loadcaseFromTag(p)
             if p.set is None:
-                nodeset = arange(calpyModel.nnodes)
+                nodeset = np.arange(calpyModel.nnodes)
             else:
                 nodeset = p.set
             F = [0.0, 0.0]
@@ -836,14 +837,14 @@ def runCalpyAnalysis(jobname=None, verbose=False, flavia=False):
         fe_util.PrintNodes(coords)
 
     # Boundary conditions
-    bcon = zeros((calpyModel.nnodes, 2), dtype=int32)
+    bcon = np.zeros((calpyModel.nnodes, 2), dtype=int32)
     bcon[:, 2:6] = 1  # leave only ux and uy
     for p in PDB.getProp(kind='n', attr=['bound']):
-        bnd = where(p.bound)[0]
+        bnd = np.where(p.bound)[0]
         if p.set is None:
-            nod = arange(calpyModel.nnodes)
+            nod = np.arange(calpyModel.nnodes)
         else:
-            nod = array(p.set)
+            nod = np.array(p.set)
         for i in bnd:
             bcon[p.set, i] = 1
     fe_util.NumberEquations(bcon)
@@ -859,7 +860,7 @@ def runCalpyAnalysis(jobname=None, verbose=False, flavia=False):
     secprops = PDB.getProp(kind='e', attr=['section'])
 
     # E, nu, thickness, rho
-    mats = array([[mat.young_modulus,
+    mats = np.array([[mat.young_modulus,
                    mat.poisson_ratio,
                    mat.thickness,
                    0.0,      # rho was not defined in material
@@ -882,7 +883,7 @@ def runCalpyAnalysis(jobname=None, verbose=False, flavia=False):
     #    matnr,  node1, node2, ....
     # Also notice that Calpy numbering starts at 1, not at 0 as customary
     # in pyFormex; therefore we add 1 to elems.
-    matnr = zeros(calpyModel.nelems, dtype=int32)
+    matnr = np.zeros(calpyModel.nelems, dtype=int32)
     for i, mat in enumerate(secprops):  # proces in same order as above!
         matnr[mat.set] = i+1
 
@@ -924,11 +925,11 @@ def runCalpyAnalysis(jobname=None, verbose=False, flavia=False):
     # Also notice that the indexing inside the bcon array uses numpy
     # convention (starting at 0), thus no adding 1 is needed!
     print("Assembling Concentrated Loads")
-    f = zeros((calpyModel.ndof, calpyModel.nloads), float)
+    f = np.zeros((calpyModel.ndof, calpyModel.nloads), float)
     for p in PDB.getProp('n', attr=['cload']):
         lc = loadcaseFromTag(p)-1  # calpy loadcases start from 0
         if p.set is None:
-            nodeset = arange(calpyModel.nnodes)
+            nodeset = np.arange(calpyModel.nnodes)
         else:
             nodeset = p.set
         F = [0.0, 0.0]
@@ -1038,7 +1039,7 @@ def runCalpyAnalysis(jobname=None, verbose=False, flavia=False):
     DB = FeResult()
     DB.nodes = model.coords
     DB.nnodes = model.coords.shape[0]
-    DB.nodid = arange(DB.nnodes)
+    DB.nodid = np.arange(DB.nnodes)
     DB.elems = {}
     for i,e in enumerate(model.elems):
         DB.elems[i] = Elems(e,eltype='quad4')
@@ -1047,7 +1048,7 @@ def runCalpyAnalysis(jobname=None, verbose=False, flavia=False):
     DB.datasize['S'] = 3
     for lc in range(calpyModel.nloads):
         DB.Increment(lc, 1)
-        d = zeros((calpyModel.nnodes, 3))
+        d = np.zeros((calpyModel.nnodes, 3))
         d[:, :2] = displ[:, :, lc]
         DB.R['U'] = d
         DB.R['S'] = stresn
@@ -1075,7 +1076,7 @@ def autoRun(quadratic=False):
     if quadratic:
         convertQuadratic()
     createModel()
-    nodenrs = arange(model.coords.shape[0])
+    nodenrs = np.arange(model.coords.shape[0])
     PDB.elemProp(eltype='CPS4', section=ElemSection(section=section, material=material))
     if quadratic:
         ny *= 2
@@ -1090,13 +1091,13 @@ def autoRun2():
     createRectPart(dict(x0=0., x2=1., y0=0., y2=1., nx=nx, ny=ny, eltype='quad'))
     convertQuadratic()
     createModel()
-    nodenrs = arange(model.coords.shape[0])
+    nodenrs = np.arange(model.coords.shape[0])
     xmin, xmax = model.coords.bbox()[:, 0]
     xtol = (xmax-xmin) / 1000.
     left = model.coords.test(dir=0, min=xmin-xtol, max=xmin+xtol)
     right = model.coords.test(dir=0, min=xmax-xtol, max=xmax+xtol)
-    leftnrs = where(left)[0]
-    rightnrs = where(right)[0]
+    leftnrs = np.where(left)[0]
+    rightnrs = np.where(right)[0]
     print(leftnrs)
     print(rightnrs)
 
@@ -1116,7 +1117,7 @@ def autoConv():
     ny = res['ny']
     createRectPart(dict(x0=0., x1=10., y0=0., y1=1., nx=nx, ny=ny, eltype='quad'))
     createModel()
-    nodenrs = arange(model.coords.shape[0])
+    nodenrs = np.arange(model.coords.shape[0])
     PDB.elemProp(eltype='CPS4', section=ElemSection(section=section))
     PDB.nodeProp(set=nodenrs[:ny+1], bound=[1, 1, 0, 0, 0, 0])
     PDB.nodeProp(set=nodenrs[-(ny+1):], cload=[0., 1./(ny+1), 0., 0., 0., 0.])
@@ -1132,7 +1133,9 @@ def exportAll():
 #############################################################################
 ######### Create a menu with interactive tasks #############
 
-def create_menu():
+# TODO: This could/should use the PluginMenu facility
+
+def create_menu(before='help'):
     """Create the FeEx menu."""
     MenuData = [
         ("&Delete All", deleteAll),
@@ -1169,8 +1172,7 @@ def create_menu():
         ("---", None),
         ("&Close Menu", close_menu),
         ]
-    return menu.Menu('FeEx', items=MenuData, parent=pf.GUI.menu, before='help')
-
+    return menu.Menu('FeEx', items=MenuData, parent=pf.GUI.menu, before=before)
 
 def show_menu():
     """Show the menu."""
@@ -1191,7 +1193,7 @@ def reload_menu():
 
 ## app main function ##
 def run():
-    geometry_menu.show_menu()
+    PluginMenu.get('Geometry').show()
     resetData()
     reset()
     reload_menu()
