@@ -31,6 +31,7 @@ _level = 'advanced'
 _topics = ['geometry', 'FEA', 'domes', 'surface']
 _techniques = ['menu', 'dialog', 'persistence', 'color']
 
+import time
 from pyformex.gui.draw import *
 
 from pyformex import simple, utils
@@ -38,7 +39,6 @@ from pyformex.connectivity import Connectivity
 from pyformex.plugins.properties import *
 from pyformex.plugins.fe_abq import *
 from pyformex.gui import menu
-import time
 
 
 def howto():
@@ -117,8 +117,8 @@ def createGeometry():
     # The base angles thus are (180-72)/2 = 54 degrees.
 
     # Ratio of the height of the isosceles triangle over the icosaeder edge length.
-    c = 0.5*tand(54.)
-    angle = arccosd(tand(54.)/sqrt(3.))
+    c = 0.5*at.tand(54.)
+    angle = at.arccosd(at.tand(54.)/sqrt(3.))
     print("Rotation Ratio: %s; Angle: %s degrees" % (c, angle))
     F = F.rotate(angle, 0)
     clear()
@@ -288,12 +288,12 @@ def createFrameModel():
 
     # Remove the edges between to quad triangles
     drawNumbers(S.coords)
-    quadtri = where(S.prop==6)[0]
+    quadtri = np.where(S.prop==6)[0]
     nquadtri = quadtri.shape[0]
     print("%s triangles are part of quadrilateral faces" % nquadtri)
     faces = S.getElemEdges()[quadtri]
-    cnt, ind, xbin = histogram2(faces.reshape(-1), arange(faces.max()+1))
-    rem = where(cnt==2)[0]
+    cnt, ind, xbin = histogram2(faces.reshape(-1), np.arange(faces.max()+1))
+    rem = np.where(cnt==2)[0]
     print("Total edges %s" % len(S.edges))
     print("Removing %s edges" % len(rem))
     edges = S.edges[complement(rem, n=len(S.edges))]
@@ -387,7 +387,7 @@ def createFrameModel():
     for lc in ['Steel', 'Glass', 'Snow']:
         if res[lc]:
             nlc += 1
-    NODLoad = zeros((nlc, S.ncoords(), 3))
+    NODLoad = np.zeros((nlc, S.ncoords(), 3))
 
     nlc = 0
     if res['Steel']:
@@ -427,7 +427,7 @@ def createFrameModel():
             PDB.nodeProp(tag=lc, set=i, cload=[P[0], P[1], P[2], 0., 0., 0.])
 
     # Get support nodes
-    botnodes = where(np.isclose(nodes[:, 2], 0.0))[0]
+    botnodes = np.where(np.isclose(nodes[:, 2], 0.0))[0]
     bot = nodes[botnodes]
     print("There are %s support nodes." % bot.shape[0])
 
@@ -435,14 +435,14 @@ def createFrameModel():
     nnodes = nodes.shape[0]              # node number offset
     ntubes = tubes.shape[0]              # element number offset
 
-    PDB.elemProp(set=arange(ntubes), section=tubesection, eltype='FRAME3D')
+    PDB.elemProp(set=np.arange(ntubes), section=tubesection, eltype='FRAME3D')
 
     # Create support systems (vertical beams)
     bot2 = bot + [0., 0., -200.]         # new nodes 200mm below bot
-    botnodes2 = arange(botnodes.shape[0]) + nnodes  # node numbers
-    nodes = concatenate([nodes, bot2])
-    supports = column_stack([botnodes, botnodes2])
-    elems = concatenate([tubes, supports])
+    botnodes2 = np.arange(botnodes.shape[0]) + nnodes  # node numbers
+    nodes = np.concatenate([nodes, bot2])
+    supports = np.column_stack([botnodes, botnodes2])
+    elems = np.concatenate([tubes, supports])
     ## !!!
     ## THIS SHOULD BE FIXED !!!
     supportsection = ElemSection(material=steel, section={
@@ -453,7 +453,7 @@ def createFrameModel():
         'moment_inertia_12': I12,
         'torsional_constant': J
         })
-    PDB.elemProp(set=arange(ntubes, elems.shape[0]), section=supportsection, eltype='FRAME3D')
+    PDB.elemProp(set=np.arange(ntubes, elems.shape[0]), section=supportsection, eltype='FRAME3D')
 
     # Finally, the botnodes2 get the support conditions
     botnodes = botnodes2
@@ -517,7 +517,7 @@ def createShellModel():
 
     PDB = PropertyDB()
     # All elements have same property:
-    PDB.elemProp(set=arange(S.nelems()), section=glasssection, eltype='STRI3')
+    PDB.elemProp(set=np.arange(S.nelems()), section=glasssection, eltype='STRI3')
 
     # Calculate the nodal loads
 
@@ -533,7 +533,7 @@ def createShellModel():
     step = 0
     if res['Glass']:
         step += 1
-        NODLoad = zeros((S.ncoords(), 3))
+        NODLoad = np.zeros((S.ncoords(), 3))
         # add the GLASS weight
         wgt = 450e-6  # N/mm**2
         # Or, calculate weight from density:
@@ -547,7 +547,7 @@ def createShellModel():
 
     if res['Snow']:
         step += 1
-        NODLoad = zeros((S.ncoords(), 3))
+        NODLoad = np.zeros((S.ncoords(), 3))
         # add NON UNIFORM SNOW
         fn = '../data/hesperia-nieve.prop'
         snowp = fromfile(fn, sep=',')
@@ -561,12 +561,12 @@ def createShellModel():
             PDB.nodeProp(tag=step, set=[i], cload=[P[0], P[1], P[2], 0., 0., 0.])
 
     # Get support nodes
-    botnodes = where(np.isclose(S.coords[:, 2], 0.0))[0]
+    botnodes = np.where(np.isclose(S.coords[:, 2], 0.0))[0]
     bot = S.coords[botnodes].reshape((-1, 1, 3))
     print("There are %s support nodes." % bot.shape[0])
 
     botofs = bot + [0., 0., -0.2]
-    bbot2 = concatenate([bot, botofs], axis=1)
+    bbot2 = np.concatenate([bot, botofs], axis=1)
     print(bbot2.shape)
     Sup = Formex(bbot2)
     draw(Sup)
@@ -695,8 +695,8 @@ def runCalpyAnalysis():
     #
     # !!! This is ok for the support beams, but for the structural beams
     # !!! this should be changed to the center of the sphere !!!
-    extra_node = array([[0.0, 0.0, 0.0]])
-    coords = concatenate([FE.nodes, extra_node])
+    extra_node = np.array([[0.0, 0.0, 0.0]])
+    coords = np.concatenate([FE.nodes, extra_node])
     nnod = coords.shape[0]
     print("Adding a node for orientation: %s" % nnod)
 
@@ -706,7 +706,7 @@ def runCalpyAnalysis():
     # Beam Properties in Calpy consist of 7 values:
     #   E, G, rho, A, Izz, Iyy, J
     # The beam y-axis lies in the plane of the 3 nodes i,j,k.
-    mats = array([[mat.young_modulus,
+    mats = np.array([[mat.young_modulus,
                   mat.shear_modulus,
                   mat.density,
                   mat.cross_section,
@@ -728,10 +728,10 @@ def runCalpyAnalysis():
     # in pyFormex; therefore we add 1 to elems.
     # The third node for all beams is the last (extra) node, numbered nnod.
     # We need to reshape tubeprops to allow concatenation
-    matnr = zeros(nel, dtype=int32)
+    matnr = np.zeros(nel, dtype=int32)
     for i, mat in enumerate(matprops):  # proces in same order as above!
         matnr[mat.set] = i+1
-    elements = concatenate([FE.elems + 1,         # the normal node numbers
+    elements = np.concatenate([FE.elems + 1,         # the normal node numbers
                             nnod * ones(shape=(nel, 1), dtype=int),  # extra node
                             matnr.reshape((-1, 1))],  # mat number
                            axis=1)
@@ -791,9 +791,9 @@ def runCalpyAnalysis():
     # convention (starting at 0), thus no adding 1 is needed!
     print("Assembling Concentrated Loads")
     nlc = 1
-    loads = zeros((ndof, nlc), float)
+    loads = np.zeros((ndof, nlc), float)
     for p in FE.prop.getProp('n', attr=['cload']):
-        cload = zeros(6)
+        cload = np.zeros(6)
         for i, v in p.cload:
             cload[i] += v
         print(cload)
@@ -899,7 +899,9 @@ def postCalpy():
 #############################################################################
 ######### Create a menu with interactive tasks #############
 
-def create_menu():
+# TODO: This could/should use the PluginMenu facility
+
+def create_menu(before='help'):
     """Create the Hesperia menu."""
     MenuData = [
         ("&How To Use", howto),
@@ -920,7 +922,7 @@ def create_menu():
         ("---", None),
         ("&Close Menu", close_menu),
         ]
-    return menu.Menu('Hesperia', items=MenuData, parent=pf.GUI.menu, before='help')
+    return menu.Menu('Hesperia', items=MenuData, parent=pf.GUI.menu, before=before)
 
 
 def show_menu():
