@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2021 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 2.6  (Mon Aug 23 15:13:50 CEST 2021)
+##  This file is part of pyFormex 3.0  (Mon Nov 22 14:32:59 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -127,82 +127,67 @@ The 'pyformex --remove' command should be executed from outside the source.
         return
 
     # If we get here, this is probably an install from tarball release
-
     # Remove the installation
-    import glob
-    prefixdir = pyformexdir.commonpath('/usr/local')
-    bindir = prefixdir / 'bin'
-    egginfo = pyformexdir.with_name(
-        "pyformex-%s.egg-info" % (pf.__version__.replace('-', '_'))
-    )
-    print("egginfo = %s" % egginfo)
-    script = bindir / 'pyformex'
-    print("script = %s" % script)
+    installdir = pyformexdir.parent
+    pyfver = f"{pf.__prog__}-{pf.__version__}"
 
-    # This Python version
-    this = '3'
-    other = ''
+    if installdir.name != pyfver:
+        print("INSTALLDIR = {installdir}")
+        print("VERSION = {pyfver}")
+        print("Version doesn't match installdir")
+        sys.exit()
 
-    scripts = [script] + glob.glob(script + '-*')
-    gtsexe = ['gtscoarsen', 'gtsinside', 'gtsrefine', 'gtsset', 'gtssmooth']
-    scripts += [bindir / g for g in gtsexe]
-    scripts = [ Path(p) for p in scripts ]
-    scripts = [ p for p in scripts if p.exists() ]
-    datadir = prefixdir / 'share'
-    data = [
-        datadir / 'man/man1' / f for f in [
-            'pyformex.1', 'pyformex-dxfparser.1', 'pyformex-postabq.1',
-            'gtscoarsen.1', 'gtsinside.1', 'gtsrefine.1', 'gtsset.1',
-            'gtssmooth.1'
-        ]
-    ]
-    data += [
-        datadir / f for f in [
-            'applications/pyformex.desktop',
-            'pixmaps/pyformex-64x64.png',
-            'pixmaps/pyformex.xpm',
-        ]
-    ]
-    data = [ Path(p) for p in data ]
-    data = [ p for p in data if p.exists() ]
-    other_files = scripts + data
+    if pf.installtype == 'U':
+        # installed in user space
+        homedir = Path.home()
+        bindir = homedir / 'bin'
+    elif pf.installtype == 'R':
+        # installed in root space
+        homedir = Path.home()
+        bindir = Path('/usr/local/bin')
+    else:
+        raise ImplementationError("This should not happen")
+    otherfiles = []
+    script = bindir / pyfver
+    if script.exists():
+        otherfiles.append(script)
+    script1 = bindir / 'pyformex'
+    print(script)
+    print(script1)
+    is_default = script1.exists() and script1.resolve() == script.resolve()
+    if is_default:
+        otherfiles.append(script1)
 
-    do_other = 'REMOVE'
-
-    print(
-        """
+    print(f"""
 ############ BEWARE!
 This procedure will:
-- %s the complete Python%s pyFormex installation in %s,
-- %s the pyFormex executable(s) (%s) in %s,
-- %s some pyFormex data files (%s) in %s.
+- remove the complete pyFormex installation in
+  {installdir}
+- remove the pyFormex executable: {script}
+""")
+    if is_default:
+        print(f"- remove the default pyFormex executable {script1}")
 
-You should only use this on a pyFormex installed from a source .tar.gz release
-with the command 'python3 setup.py install'.
+    print(f"""\
+You should only use this on a pyFormex installed from source with the command:
+  ./install.sh
 You need proper permissions to actually delete the files.
 After successful removal, you will not be able to run this pyFormex again,
 unless you re-install it.
-""" % (
-            'REMOVE', this, pyformexdir, do_other, ', '.join(
-                [p.name for p in scripts]
-            ), bindir, do_other, ', '.join([p.name for p in data]), datadir
-        )
-    )
-
-    s = input("Are you sure you want to remove pyFormex? yes/NO: ")
+If you have another pyFormex version installed, you can make that the default
+by running pyformex-VERSION --make_default
+""")
+    s = input(f"Are you sure you want to remove {pyfver}? yes/NO: ")
     if s == 'yes':
-        print(f"Removing pyformex tree: {pyformexdir}")
-        pyformexdir.removeTree()
-        if egginfo.exists():
-            egginfo.unlink()
+        print(f"Removing pyformex tree: {installdir}")
+        installdir.removeTree()
 
-        if other == '':
-            for f in other_files:
-                print(f"Removing {f}")
-                try:
-                    Path(f).unlink()
-                except Exception:
-                    print(f"Could not remove {f}")
+        for f in otherfiles:
+            print(f"Removing {f}")
+            try:
+                Path(f).unlink()
+            except Exception:
+                print(f"Could not remove {f}")
 
         print("\nBye, bye! I won't be back until you reinstall me!")
     elif s.startswith('y') or s.startswith('Y'):
@@ -308,11 +293,7 @@ def run_doctest(modules):
     This implements the `pyformex --doctest` functionality.
     """
     import numpy
-    if software.Module.check('numpy', '< 1.14'):
-        # does not have the legacy argument
-        numpy.set_printoptions(precision=2, suppress=True)
-    else:
-        numpy.set_printoptions(precision=2, suppress=True, legacy='1.13')
+    numpy.set_printoptions(precision=2, suppress=True)
     from pyformex import arraytools
     numpy.set_string_function(arraytools.array2str)
     # safe_verbosityset verbosity to 0
@@ -344,7 +325,7 @@ def run_doctest(modules):
         todo.append(m)
 
     # Remove modules that we can not test:
-    todo = [ m for m in todo if 'vtk' not in m and 'vmtk' not in m ]
+    todo = [ m for m in todo if 'vtk' not in m ]
     if not software.Module.has('meshio'):
         todo.remove('meshio')
 
@@ -384,10 +365,15 @@ def doctest_module(module):
     """
     import doctest
     import importlib
+    import numpy
 
     if not module.startswith('pyformex'):
         module = 'pyformex.' + module
     mod = importlib.import_module(module)
+    printoptions = getattr(mod, '_numpy_printoptions_', {})
+    if printoptions:
+        #print(f"Set numpy print options: {printoptions}")
+        numpy.set_printoptions(**printoptions)
 
     pf.options.verbose = 0
     with warnings.catch_warnings():
