@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2021 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 2.6  (Mon Aug 23 15:13:50 CEST 2021)
+##  This file is part of pyFormex 3.0  (Mon Nov 22 14:32:59 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -95,32 +95,17 @@ class CoordSys(object):
     to its internal data. Of these, `trl` and `rot` can be used to set
     the data of the CoordSys and thus change the CoordSys in-place.
 
-    Attributes
-    ----------
-    trl: float array (3,)
-        The origin of the CoordSys
-    rot: float array (3,3)
-        The rotation matrix of the CoordSys
-    u: float array (3,)
-        The unit vector along the first axis (0).
-    v: float array (3,)
-        The unit vector along the second axis (1).
-    w: float array (3,)
-        The unit vector along the third axis (2).
-    o: float array (3,)
-        The origin of the CoordSys.
-
     Examples
     --------
     Three points O,A,B in the xy-plane, first two parallel to x-axis,
     third at higher y-value. The resulting CoordSys is global axes
     translated to point O.
 
-    >>> OAB = Coords([[ 2.,1.,0.],[ 5.,1.,0.],[ 0.,3.,0.]])
+    >>> OAB = Coords([[2.,1.,0.],[5.,1.,0.],[0.,3.,0.]])
     >>> print(CoordSys(oab=OAB))
-    CoordSys: trl=[ 2. 1. 0.]; rot=[[ 1. 0. 0.]
-                                    [ 0. 1. 0.]
-                                    [ 0. 0. 1.]]
+    CoordSys: trl=[2. 1. 0.]; rot=[[1. 0. 0.]
+                                    [0. 1. 0.]
+                                    [0. 0. 1.]]
 
     Now translate the points so that O is on the z-axis, and rotate the
     points 30 degrees around z-axis.
@@ -132,34 +117,52 @@ class CoordSys(object):
      [-2.73  0.73  5.  ]]
     >>> C = CoordSys(oab=OAB)
     >>> print(C)
-    CoordSys: trl=[ 0. 0. 5.]; rot=[[ 0.87  0.5   0.  ]
-                                    [-0.5   0.87  0.  ]
-                                    [ 0.   -0.    1.  ]]
+    CoordSys: trl=[0. 0. 5.]; rot=[[ 0.87  0.5   0.  ]
+                                   [-0.5   0.87  0.  ]
+                                   [ 0.   -0.    1.  ]]
 
     Reverse axes x and y. The resulting CoordSys is still righthanded. This is
     equivalent to a rotation over 180 degrees around z-axis.
 
     >>> print(C.reverse(0,1))
-    CoordSys: trl=[ 0. 0. 5.]; rot=[[-0.87 -0.5  -0.  ]
-                                    [ 0.5  -0.87 -0.  ]
-                                    [ 0.   -0.    1.  ]]
+    CoordSys: trl=[0. 0. 5.]; rot=[[-0.87 -0.5  -0.  ]
+                                   [ 0.5  -0.87 -0.  ]
+                                   [ 0.   -0.    1.  ]]
 
     Now rotate C over 150 degrees around z-axis to become parallel with
     the global axes.
 
     >>> print(C.rotate(150,2))
-    CoordSys: trl=[ 0.  0.  5.]; rot=[[ 1.  0.  0.]
-                                      [-0.  1.  0.]
-                                      [ 0.  0.  1.]]
+    CoordSys: trl=[0.  0.  5.]; rot=[[ 1.  0.  0.]
+                                     [-0.  1.  0.]
+                                     [ 0.  0.  1.]]
 
     >>> C = CoordSys(trl=[0., 0., 5.],
     ...     rot=[[-0.87,-0.5,-0.], [0.5,-0.87,-0.], [0., -0., 1.]])
     >>> print(C)
-    CoordSys: trl=[ 0.  0.  5.]; rot=[[-0.87 -0.5  -0.  ]
-                                      [ 0.5  -0.87 -0.  ]
-                                      [ 0.   -0.    1.  ]]
+    CoordSys: trl=[0.  0.  5.]; rot=[[-0.87 -0.5  -0.  ]
+                                     [ 0.5  -0.87 -0.  ]
+                                     [ 0.   -0.    1.  ]]
 
     """
+    # REMOVED from docstring
+
+    # Attributes
+    # ----------
+    # trl: float array (3,)
+    #     The origin of the CoordSys
+    # rot: float array (3,3)
+    #     The rotation matrix of the CoordSys
+    # u: float array (3,)
+    #     The unit vector along the first axis (0).
+    # v: float array (3,)
+    #     The unit vector along the second axis (1).
+    # w: float array (3,)
+    #     The unit vector along the third axis (2).
+    # o: float array (3,)
+    #     The origin of the CoordSys.
+
+
     def __init__(self, oab=None, points=None, rot=None, trl=None):
         """Initialize the CoordSys"""
         if oab is not None:
@@ -340,9 +343,9 @@ class CoordSys(object):
         Examples
         --------
         >>> print(CoordSys().translate([-2.,-1.,5.]))
-        CoordSys: trl=[-2. -1.  5.]; rot=[[ 1.  0.  0.]
-                                          [ 0.  1.  0.]
-                                          [ 0.  0.  1.]]
+        CoordSys: trl=[-2. -1.  5.]; rot=[[1.  0.  0.]
+                                          [0.  1.  0.]
+                                          [0.  0.  1.]]
 
         """
         return CoordSys(points=self.points().translate(*args, **kargs))
@@ -360,9 +363,9 @@ class CoordSys(object):
         Examples
         --------
         >>> print(CoordSys().rotate(30))
-        CoordSys: trl=[ 0.  0.  0.]; rot=[[ 0.87  0.5   0.  ]
-                                          [-0.5   0.87  0.  ]
-                                          [ 0.    0.    1.  ]]
+        CoordSys: trl=[0.  0.  0.]; rot=[[ 0.87  0.5   0.  ]
+                                         [-0.5   0.87  0.  ]
+                                         [ 0.    0.    1.  ]]
 
         """
         return CoordSys(points=self.points().rotate(*args, **kargs))
@@ -385,9 +388,9 @@ class CoordSys(object):
         Examples
         --------
         >>> print(CoordSys().reverse(0,1))
-        CoordSys: trl=[ 0.  0.  0.]; rot=[[-1. -0. -0.]
-                                          [-0. -1. -0.]
-                                          [ 0.  0.  1.]]
+        CoordSys: trl=[0.  0.  0.]; rot=[[-1. -0. -0.]
+                                         [-0. -1. -0.]
+                                         [ 0.  0.  1.]]
 
         """
         for axis in axes:
