@@ -2050,7 +2050,7 @@ class Lagrange3D(ElementType):
         r = np.linspace(0, 1, dr+1)
         s = np.linspace(0, 1, ds+1)
         t = np.linspace(0, 1, dt+1)
-        s, t, r = np.meshgrid(r, s, t)  # !!! Notice order
+        t, s, r = np.meshgrid(t, s, r, indexing='ij')  # !!! Notice order
         rst = np.row_stack([r.ravel(), s.ravel(), t.ravel()])
         h =[ lagrange3(dr, ds, dt, i, j, k)
              for k in range(dt+1) for j in range(ds+1) for i in range(dr+1)]
@@ -2096,7 +2096,7 @@ class Lagrange3D(ElementType):
         else:
             t = seeds(tdiv, self.dt)
             nt = len(t)
-        s, t, r = np.meshgrid(r, s, t)
+        t, s, r = np.meshgrid(t, s, r, indexing='ij')
         H = np.stack([h(r,s,t) for h in self.h])
         return H.reshape((len(self.h), -1)).transpose()
 
