@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2021 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 2.6  (Mon Aug 23 15:13:50 CEST 2021)
+##  This file is part of pyFormex 3.0  (Mon Nov 22 14:32:59 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -63,7 +63,7 @@ def run():
     clear()
     S = Horse()
     perspective(False)
-    SA = draw(S)
+    SA = draw(S, color=black)   # Default fgcolor (darkgrey) doesn't work
     setDrawOptions(view='cur', bbox=None)
     pause()
 
