@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2021 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 2.6  (Mon Aug 23 15:13:50 CEST 2021)
+##  This file is part of pyFormex 3.0  (Mon Nov 22 14:32:59 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -36,7 +36,6 @@ _topics = ['surface', 'vtk']
 _techniques = ['inside', 'timer', 'multitask']
 
 from pyformex.gui.draw import *
-from pyformex.multi import *
 
 filename = getcfg('datadir') / 'horse.off'
 
@@ -57,11 +56,12 @@ def getData():
             _I('trl', [0., 0., 0.], itemptype='point'),
         ]),
         _I('method', choices=['gts', 'vtk']),
+        _I('multi', True, text='Allow parallel processing'),
         _I('atol', 0.001),
-        _I('nproc', 1,),
     ], enablers = [
         ('surface', 'file', 'filename', ),
         ('surface', 'sphere', 'grade', ),
+        ('method', 'gts', 'multi', ),
     ])
     res = dia.getResults()
     if res:
@@ -106,11 +106,7 @@ def create():
     return S, P
 
 
-def inside(S, P, method, atol):
-    return S.inside(P, method=method, tol=atol, multi=False)
-
-
-def testInside(S, P, method, nproc, atol):
+def testInside(S, P, method, atol, multi):
     """Test which of the points P are inside surface S"""
 
     print("Testing %s points against %s faces" % (P.nelems(), S.nelems()))
@@ -124,16 +120,7 @@ def testInside(S, P, method, nproc, atol):
         return
 
     with Timer() as t:
-        if nproc == 1:
-            ind = inside(S, P, method, atol)
-
-        else:
-            datablocks = splitar(P, nproc)
-            datalen = [0] + [d.shape[0] for d in datablocks]
-            shift = np.array(datalen[:-1]).cumsum()
-            tasks = [(inside, (S, d, method, atol)) for d in datablocks]
-            ind = multitask(tasks, nproc)
-            ind = np.concatenate([i+s for i, s in zip(ind, shift)])
+        ind = S.inside(P, method=method, tol=atol, multi=multi)
 
     print(f"{method}_inside: {P.shape[0]} points / {S.nelems()} faces:"
           f" found {len(ind)} inside points in {t.lastread} seconds")
@@ -150,8 +137,7 @@ def run():
     if getData():
         S, P = create()
         if S:
-            print(method)
-            testInside(S, P, method, nproc, atol)
+            testInside(S, P, method, atol, multi)
 
 
 if __name__ == '__draw__':
