@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2021 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 2.6  (Mon Aug 23 15:13:50 CEST 2021)
+##  This file is part of pyFormex 3.0  (Mon Nov 22 14:32:59 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -244,7 +244,7 @@ def readSplines():
     The geometry file splines.pgf is provided with the pyFormex distribution.
     """
     fn = getcfg('datadir') / 'splines.pgf'
-    obj = readGeomFile(fn)
+    obj = readGeometry(fn)
     T = obj.values()
     print("Number of curves: %s" % len(T))
     print("Curve lengths: %s" % [len(Si.coords) for Si in T])
