@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2021 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 2.6  (Mon Aug 23 15:13:50 CEST 2021)
+##  This file is part of pyFormex 3.0  (Mon Nov 22 14:32:59 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -179,26 +179,27 @@ class Geometry(ABC):
     some rules in order for all the above to work properly.
     See `UserGuide`.
 
-
-    Attributes
-    ----------
-    coords: :class:`~coords.Coords`
-        A Coords object that holds the coordinates of the points required
-        to describe the type of geometry.
-    prop: int array
-        Element property numbers. This is a 1-dim int array with length
-        :meth:`nelems`. Each element of the
-        Geometry can thus be assigned an integer value. It is up the
-        the subclass to define if and how its instances are divided into
-        elements, and how to use this element property number.
-    attrib: :class:`~attributes.Attributes`
-        An Attributes object that is primarily used to define persisting
-        drawing attributes (like color) for the Geometry object.
-    fields: OrderedDict
-        A dict with the Fields defined on the object. This atribute only
-        exists when at least one Field has been defined. See :meth:`addField`.
-
     """
+    # REMOVED for new Sphinx
+
+    # Attributes
+    # ----------
+    # coords: :class:`~coords.Coords`
+    #     A Coords object that holds the coordinates of the points required
+    #     to describe the type of geometry.
+    # prop: int array
+    #     Element property numbers. This is a 1-dim int array with length
+    #     :meth:`nelems`. Each element of the
+    #     Geometry can thus be assigned an integer value. It is up the
+    #     the subclass to define if and how its instances are divided into
+    #     elements, and how to use this element property number.
+    # attrib: :class:`~attributes.Attributes`
+    #     An Attributes object that is primarily used to define persisting
+    #     drawing attributes (like color) for the Geometry object.
+    # fields: OrderedDict
+    #     A dict with the Fields defined on the object. This atribute only
+    #     exists when at least one Field has been defined. See :meth:`addField`.
+
     # _attributes_ = [ 'xyz', 'x', 'y', 'z', 'xy', 'xz', 'yz' ]
 
 
@@ -1302,15 +1303,11 @@ class Geometry(ABC):
         This writes the Geometry to a pyFormex Geometry File (PGF) with
         the specified name.
 
-        It is a convenient shorthand for::
-
-          writeGeomFile(filename, self, sep=sep, mode=mode, **kargs)
-
-        See :func:`~script.writeGeomFile` for details.
+        See :func:`~filewrite.writePGF` for details.
 
         """
-        from pyformex.script import writeGeomFile
-        writeGeomFile(filename, self, sep=sep, mode=mode, **kargs)
+        from pyformex import filewrite
+        filewrite.writePGF(filename, self, sep=sep, mode=mode, **kargs)
 
 
     @classmethod
@@ -1320,15 +1317,11 @@ class Geometry(ABC):
         This reads a single object (the object) from a PGF file
         and returns it.
 
-        It is a convenient shorthand for::
-
-          next(readGeomFile(filename, 1).values())
-
-        See :func:`~script.readGeomFile` for details.
+        See :func:`~fileread.readPGF` for details.
 
         """
-        from pyformex.script import readGeomFile
-        res = readGeomFile(filename, 1)
+        from pyformex import fileread
+        res = fileread.readPGF(filename, 1)
         return next(iter(res.values()))
 
 
