@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2021 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 2.6  (Mon Aug 23 15:13:50 CEST 2021)
+##  This file is part of pyFormex 3.0  (Mon Nov 22 14:32:59 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -578,14 +578,11 @@ class GeometryFile(object):
         # Select the exportable attributes
         okattr = filter_attrib(attrib)
         if okattr:
-            # In case we would allow array attributes, We need to set
+            # In case we would allow array attributes, we need to set
             # numpy printoptions to display the full array, not a truncated one
-            opt = np.get_printoptions()
-            np.set_printoptions(threshold=np.inf)
-            # Get a reversible representation of the attrib dict
-            s = repr(filter_attrib(okattr))
-            # Restore the numpy printoptions
-            np.set_printoptions(**opt)
+            with np.printoptions(threshold=np.inf):
+                # Get a reversible representation of the attrib dict
+                s = repr(filter_attrib(okattr))
             # Remove the newlines, so everything can be read as a single line
             s = re.sub('\n *', '', s)
             # In case arrays are stored, remove the dtype (only int and float
@@ -770,7 +767,8 @@ class GeometryFile(object):
 
                         try:
                             # Read the color array
-                            color = at.readArray(self.fil, colortype, colorshape, sep=sep)
+                            color = at.readArray(self.fil, colortype,
+                                                 colorshape, sep=sep)
                         except Exception as e:
                             print("Invalid color array on PGF file: skipped. "
                                   f"Traceback: {e}")
