@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2021 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 2.6  (Mon Aug 23 15:13:50 CEST 2021)
+##  This file is part of pyFormex 3.0  (Mon Nov 22 14:32:59 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -56,30 +56,10 @@ Renamed functions::
 
 Planned renaming of functions::
 
-    areaNormals
-    degenerate
-    levelVolumes
-    smallestDirection
-    distance                 -> distance
-    closest
-    closestPair
-    projectedArea
-    polygonNormals
-    averageNormals
-    triangleInCircle
-    triangleCircumCircle
-    triangleBoundingCircle
-    triangleObtuse
     lineIntersection         -> to be removed (or intersect2DLineWithLine)
-    displaceLines
-    segmentOrientation
-    rotationAngle
-    anyPerpendicularVector
-    perpendicularVector
     projectionVOV            -> projectVectorOnVector
     projectionVOP            -> projectVectorOnPlane
 
-
     pointsAtLines            -> pointOnLine
     pointsAtSegments         -> pointOnSegment
     intersectionTimesLWT     -> intersectLineWithTriangle
@@ -90,13 +70,6 @@ Planned renaming of functions::
     intersectionLinesPWP     -> intersectTwoPlanes (or intersectPlaneWithPlane)
     intersectionSphereSphere -> intersectTwoSpheres (or intersectSphereWithSphere)
 
-    faceDistance             ->
-    edgeDistance             ->
-    vertexDistance           ->
-    baryCoords
-    insideSimplex
-    insideTriangle
-
 """
 import numpy as np
 
@@ -181,17 +154,17 @@ class Lines(object):
 
     >>> L = Lines([[[2.,0.,0.],[2.,3.,0.]], [[0.,1.,0.],[1.,1.,0.]]])
     >>> print(L.p)
-    [[ 2.  0.  0.]
-     [ 0.  1.  0.]]
+    [[2.  0.  0.]
+     [0.  1.  0.]]
     >>> print(L.n)
-    [[ 0.  3.  0.]
-     [ 1.  0.  0.]]
+    [[0.  3.  0.]
+     [1.  0.  0.]]
     >>> L.coords
-    Coords([[[ 2.,  0.,  0.],
-             [ 2.,  3.,  0.]],
+    Coords([[[2.,  0.,  0.],
+             [2.,  3.,  0.]],
     <BLANKLINE>
-            [[ 0.,  1.,  0.],
-             [ 1.,  1.,  0.]]])
+            [[0.,  1.,  0.],
+             [1.,  1.,  0.]]])
 
     Create the same Lines from one point and a vector.
 
@@ -367,41 +340,41 @@ def intersectLineWithLine(q1, m1, q2, m2, mode='all', times=False):
     >>> p,n = [[2.,0.,0.],[0.,0.,0.]], [[0.,1.,0.],[0.,0.,1.]]
     >>> x1,x2 = intersectLineWithLine(q,m,p,n)
     >>> print(x1)
-    [[[  2.  0.  0.]
-      [  0.  0.  0.]]
+    [[[ 2.  0.  0.]
+      [ 0.  0.  0.]]
     <BLANKLINE>
-     [[  2.  2.  1.]
-      [  0.  0.  1.]]
+     [[ 2.  2.  1.]
+      [ 0.  0.  1.]]
     <BLANKLINE>
-     [[ nan nan nan]
-      [  0.  0.  3.]]]
+     [[nan nan nan]
+      [ 0.  0.  3.]]]
     >>> print(x2)
-    [[[  2.  0.  0.]
-      [  0.  0.  0.]]
+    [[[ 2.  0.  0.]
+      [ 0.  0.  0.]]
     <BLANKLINE>
-     [[  2.  2.  0.]
-      [  0.  0.  1.]]
+     [[ 2.  2.  0.]
+      [ 0.  0.  1.]]
     <BLANKLINE>
-     [[ nan nan nan]
-      [  0.  0.  3.]]]
+     [[nan nan nan]
+      [ 0.  0.  3.]]]
 
     >>> x1,x2 = intersectLineWithLine(q[:2],m[:2],p,n,mode='pair')
     >>> print(x1)
-    [[ 2. 0. 0.]
-     [ 0. 0. 1.]]
+    [[2. 0. 0.]
+     [0. 0. 1.]]
     >>> print(x2)
-    [[ 2. 0. 0.]
-     [ 0. 0. 1.]]
+    [[2. 0. 0.]
+     [0. 0. 1.]]
 
     >>> t1,t2 = intersectLineWithLine(q,m,p,n,times=True)
     >>> print(t1)
-    [[  2. -0.]
-     [  2. -0.]
-     [ nan -0.]]
+    [[ 2. -0.]
+     [ 2. -0.]
+     [nan -0.]]
     >>> print(t2)
-    [[ -0. -0.]
-     [  2.  1.]
-     [ nan  3.]]
+    [[-0. -0.]
+     [ 2.  1.]
+     [nan  3.]]
 
     >>> t1,t2 = intersectLineWithLine(q[:2],m[:2],p,n,mode='pair',times=True)
     >>> print(t1)
@@ -486,23 +459,23 @@ def intersectLineWithPlane(q, m, p, n, mode='all', times=False):
 
     >>> t = intersectLineWithPlane(q,m,p,n,times=True)
     >>> print(t)
-    [[  2.  3.]
-     [  1.  2.]
-     [ inf  0.]]
+    [[ 2.  3.]
+     [ 1.  2.]
+     [inf  0.]]
     >>> x = intersectLineWithPlane(q,m,p,n)
     >>> print(x)
-    [[[  2.  0.  0.]
-      [  3.  0.  0.]]
+    [[[ 2.  0.  0.]
+      [ 3.  0.  0.]]
     <BLANKLINE>
-     [[  0.  2.  0.]
-      [  0.  3.  0.]]
+     [[ 0.  2.  0.]
+      [ 0.  3.  0.]]
     <BLANKLINE>
-     [[ nan nan inf]
-      [  0.  0.  3.]]]
+     [[nan nan inf]
+      [ 0.  0.  3.]]]
     >>> x = intersectLineWithPlane(q[:2],m[:2],p,n,mode='pair')
     >>> print(x)
-    [[ 2. 0. 0.]
-     [ 0. 3. 0.]]
+    [[2. 0. 0.]
+     [0. 3. 0.]]
 
     """
     q = at.checkArray(q, (-1, 3), 'f', 'i')
@@ -609,10 +582,10 @@ def intersectSegmentWithPlane(s, p, n, mode='all', atol=0., returns='x'):
 
     >>> x, ind = intersectSegmentWithPlane(X, P[:2], n[:2], returns='xi')
     >>> print(x)
-    [[ 0.3  0.   0. ]
-     [ 1.   0.5  0. ]
-     [ 0.3  0.3  0. ]
-     [ 0.5  0.5  0. ]]
+    [[0.3  0.   0. ]
+     [1.   0.5  0. ]
+     [0.3  0.3  0. ]
+     [0.5  0.5  0. ]]
     >>> print(ind)
     [[0 0]
      [1 1]
@@ -623,8 +596,8 @@ def intersectSegmentWithPlane(s, p, n, mode='all', atol=0., returns='x'):
 
     >>> x, ind = intersectSegmentWithPlane(X, P, n, mode='pair', returns='xi')
     >>> print(x)
-    [[ 0.3  0.   0. ]
-     [ 1.   0.5  0. ]]
+    [[0.3  0.   0. ]
+     [1.   0.5  0. ]]
     >>> print(ind)
     [0 1]
 
@@ -725,9 +698,9 @@ def intersectLineWithTriangle(T, p, p1, method='line', atol=1.e-5):
     ...             ])
     >>> P, ind = intersectLineWithTriangle(T, L[:,0,:], L[:,1,:])
     >>> print(P)
-    [[ 0.   0.   0. ]
-     [ 0.5  0.5  0. ]
-     [ 0.2  0.7  0. ]]
+    [[0.   0.   0. ]
+     [0.5  0.5  0. ]
+     [0.2  0.7  0. ]]
     >>> print(ind)
     [[0 0 0]
      [0 0 1]
@@ -737,8 +710,8 @@ def intersectLineWithTriangle(T, p, p1, method='line', atol=1.e-5):
     >>> P, ind = intersectLineWithTriangle(T, L[:,0,:], L[:,1,:],
     ...          method='ray')
     >>> print(P)
-    [[ 0.   0.   0. ]
-     [ 0.2  0.7  0. ]]
+    [[0.   0.   0. ]
+     [0.2  0.7  0. ]]
     >>> print(ind)
     [[0 0 0]
      [0 0 1]
@@ -746,7 +719,7 @@ def intersectLineWithTriangle(T, p, p1, method='line', atol=1.e-5):
     >>> P, ind = intersectLineWithTriangle(T, L[:,0,:], L[:,1,:],
     ...          method='segment')
     >>> print(P)
-    [[ 0.  0.  0.]]
+    [[0.  0.  0.]]
     >>> print(ind)
     [[0 0 0]
      [0 0 1]]
@@ -1045,17 +1018,17 @@ def projectPointOnPlane(X, p, n, mode='all'):
     >>> X = Coords([[0.,1.,0.],[3.,0.,0.],[4.,3.,0.]])
     >>> p,n = [[2.,0.,0.],[0.,1.,0.]], [[1.,0.,0.],[0.,1.,0.]]
     >>> print(projectPointOnPlane(X,p,n))
-    [[[ 2. 1. 0.]
-      [ 0. 1. 0.]]
+    [[[2. 1. 0.]
+      [0. 1. 0.]]
     <BLANKLINE>
-     [[ 2. 0. 0.]
-      [ 3. 1. 0.]]
+     [[2. 0. 0.]
+      [3. 1. 0.]]
     <BLANKLINE>
-     [[ 2. 3. 0.]
-      [ 4. 1. 0.]]]
+     [[2. 3. 0.]
+      [4. 1. 0.]]]
     >>> print(projectPointOnPlane(X[:2],p,n,mode='pair'))
-    [[ 2. 1. 0.]
-     [ 3. 1. 0.]]
+    [[2. 1. 0.]
+     [3. 1. 0.]]
 
     """
     X = np.asarray(X).reshape(-1, 3)
@@ -1089,7 +1062,7 @@ def projectPointOnPlaneTimes(X, p, n, mode='all'):
      [-1.  1.]
      [-2. -2.]]
     >>> print(projectPointOnPlaneTimes(X[:2],p,n,mode='pair'))
-    [ 2. 1.]
+    [2. 1.]
 
     """
     if mode == 'all':
@@ -1121,17 +1094,17 @@ def projectPointOnLine(X, p, n, mode='all'):
     >>> X = Coords([[0.,1.,0.],[3.,0.,0.],[4.,3.,0.]])
     >>> p,n = [[2.,0.,0.],[0.,1.,0.]], [[0.,2.,0.],[1.,0.,0.]]
     >>> print(projectPointOnLine(X,p,n))
-    [[[ 2. 1. 0.]
-      [ 0. 1. 0.]]
+    [[[2. 1. 0.]
+      [0. 1. 0.]]
     <BLANKLINE>
-     [[ 2. 0. 0.]
-      [ 3. 1. 0.]]
+     [[2. 0. 0.]
+      [3. 1. 0.]]
     <BLANKLINE>
-     [[ 2. 3. 0.]
-      [ 4. 1. 0.]]]
+     [[2. 3. 0.]
+      [4. 1. 0.]]]
     >>> print(projectPointOnLine(X[:2],p,n,mode='pair'))
-    [[ 2. 1. 0.]
-     [ 3. 1. 0.]]
+    [[2. 1. 0.]
+     [3. 1. 0.]]
 
     """
     X = np.asarray(X).reshape(-1, 3)
@@ -1159,11 +1132,11 @@ def projectPointOnLineTimes(X, p, n, mode='all'):
     >>> X = Coords([[0.,1.,0.],[3.,0.,0.],[4.,3.,0.]])
     >>> p,n = [[2.,0.,0.],[0.,1.,0.]], [[0.,1.,0.],[1.,0.,0.]]
     >>> print(projectPointOnLineTimes(X,p,n))
-    [[ 1. 0.]
-     [ 0. 3.]
-     [ 3. 4.]]
+    [[1. 0.]
+     [0. 3.]
+     [3. 4.]]
     >>> print(projectPointOnLineTimes(X[:2],p,n,mode='pair'))
-    [ 1. 3.]
+    [1. 3.]
 
     """
     if mode == 'all':
@@ -1209,18 +1182,18 @@ def distanceFromLine(X, lines, mode='all'):
     >>> X = Coords([[0.,1.,0.],[3.,0.,0.],[4.,3.,0.]])
     >>> L = Lines(([[2.,0.,0.],[0.,1.,0.]], [[0.,3.,0.],[1.,0.,0.]]))
     >>> print(distanceFromLine(X,L))
-    [[ 2. 0.]
-     [ 1. 1.]
-     [ 2. 2.]]
+    [[2. 0.]
+     [1. 1.]
+     [2. 2.]]
     >>> print(distanceFromLine(X[:2],L,mode='pair'))
-    [ 2. 1.]
+    [2. 1.]
     >>> L = Lines(([[[2.,0.,0.],[2.,2.,0.]], [[0.,1.,0.],[1.,1.,0.]]]))
     >>> print(distanceFromLine(X,L))
-    [[ 2. 0.]
-     [ 1. 1.]
-     [ 2. 2.]]
+    [[2. 0.]
+     [1. 1.]
+     [2. 2.]]
     >>> print(distanceFromLine(X[:2],L,mode='pair'))
-    [ 2. 1.]
+    [2. 1.]
 
     """
     lines = Lines(lines)
@@ -1301,7 +1274,7 @@ def faceDistance(X, Fp, return_points=False):
     # Compute projection of points X on facets F
     Y = projectPointOnPlane(X, Fp[:, 0, :], Fn)
     # Find intersection points Y inside the facets
-    inside = insideTriangle(Fp, Y)
+    inside = insideTriangle(Fp, Y.swapaxes(0,1)).swapaxes(0,1)
     pid = np.where(inside)[0]
     if pid.size == 0:
         if return_points:
@@ -1444,7 +1417,7 @@ def hexVolume(x):
     >>> from pyformex.elements import Hex8
     >>> X = Coords(Hex8.vertices).reshape(-1,8,3)
     >>> print(hexVolume(X))
-    [ 1.]
+    [1.]
 
     """
     x = at.checkArray(x, shape=(-1, 8, 3), kind='f')
@@ -1664,56 +1637,217 @@ def projectedArea(x, dir):
     return 0.5 * area.sum()
 
 
-def polygonNormals(x):
-    """Compute normals in all points of polygons in x.
+def polygonVectorPairs(x):
+    """Compute vector pairs of the edges at each vertex of the polygons.
 
-    x is an (nel,nplex,3) coordinate array representing nel (possibly nonplanar)
-    polygons.
+    Parameters
+    ----------
+    x: float :term:`array_like` (nel,nplex,3)
+        Array with the coordinates of the vertices of nel polygons, each having
+        nplex vertices.The polygons may be nonplanar.
 
-    The return value is an (nel,nplex,3) array with the unit normals on the
-    two edges ending in each point.
+    Returns
+    -------
+    vec1: float array (nel, nplex, 3)
+        The vectors from each vertex to the previous vertex in the polygon.
+    vec1: float array (nel, nplex, 3)
+        The vectors from each vertex to the next vertex in the polygon.
+
+    Examples
+    --------
+    >>> from pyformex.formex import Formex
+    >>> F = Formex('3:164')
+    >>> v1,v2 = polygonVectorPairs(F.coords)
+    >>> print(v1)
+    [[[ 1.  0.  0.]
+      [-1.  1.  0.]
+      [ 0. -1.  0.]]]
+    >>> print(v2)
+    [[[-1.  1.  0.]
+      [ 0. -1.  0.]
+      [ 1.  0.  0.]]]
+    >>> F = Formex('l:1')
+    >>> v1,v2 = polygonVectorPairs(F.coords)
+    >>> print(v1)
+    [[[-1.  0.  0.]
+      [ 1.  0.  0.]]]
+    >>> print(v2)
+    [[[ 1.  0.  0.]
+      [-1.  0.  0.]]]
 
     """
-    if x.shape[1] < 3:
-        # raise ValueError("Cannot compute normals for plex-2 elements"
-        n = np.zeros_like(x)
-        n[:, :, 2] = -1.
-        return n
+    # # TODO: fix this in drawing??
+    # if x.shape[1] < 3:
+    #     # raise ValueError("Cannot compute normals for plex-2 elements"
+    #     # ! No error here because we need it for drawing!
+    #     n = np.zeros_like(x)
+    #     n[:, :, 2] = -1.
+    #     return n
 
     ni = np.arange(x.shape[1])
     nj = np.roll(ni, 1)
     nk = np.roll(ni, -1)
     v1 = x-x[:, nj]
     v2 = x[:, nk]-x
-    n = at.vectorPairNormals(v1.reshape(-1, 3),
-                             v2.reshape(-1, 3)).reshape(x.shape)
-    return n
+    return v1, v2
 
 
-def averageNormals(coords, elems, atNodes=False, treshold=None):
-    """Compute average normals at all points of elems.
+def polygonNormals(x, return_angles=False):
+    """Compute normals in all points of polygons in x.
 
-    coords is a (ncoords,3) array of nodal coordinates.
-    elems is an (nel,nplex) array of element connectivity.
+    Parameters
+    ----------
+    x: float :term:`array_like` (nel,nplex,3)
+        Array with the coordinates of the vertices of nel polygons, each having
+        nplex vertices.The polygons may be nonplanar.
+    return_angles: bool
+        If True, also returns the angle at all vetices of the polygons.
 
-    The default return value is an (nel,nplex,3) array with the averaged
-    unit normals in all points of all elements.
-    If atNodes == True, a more compact array with the unique averages
-    at the nodes is returned.
+    Returns
+    -------
+    normals: float array (nel,nplex,3)
+        The unit normals on the two edges ending at each vertex.
+    angles: float array (nel, nplex)
+        Only returned if return_angles=True: the angles made by the
+        two polygon edges at each vertex.
 
+    See Also
+    --------
+    polygonAvgNormals: compute averaged normals at the nodes
+
+    Examples
+    --------
+    >>> from pyformex.formex import Formex
+    >>> F = Formex('3:164')
+    >>> n, a = polygonNormals(F.coords, return_angles=True)
+    >>> print(n)
+    [[[ 0. -0.  1.]
+      [ 0.  0.  1.]
+      [-0.  0.  1.]]]
+    >>> print(a)
+    [[45. 45. 90.]]
     """
-    if treshold is not None:
-        # TODO: AVERAGE NORMALS THRESHOLD IS NOT IMPLEMENTED!
-        pass
-    normals = polygonNormals(coords[elems])
+    if x.shape[1] < 3:
+        normals = np.zeros_like(x)
+        normals[:, :, 2] = -1.
+        if return_angles:
+            angles = np.zeros_like(x[..., 0])
+
+    else:
+        v1, v2 = polygonVectorPairs(x)
+        normals = at.vectorPairNormals(v1.reshape(-1, 3),
+                                       v2.reshape(-1, 3)).reshape(x.shape)
+        if return_angles:
+            angles = 180. - at.vectorPairAngle(v1, v2)
+
+    if return_angles:
+        return normals, angles
+    else:
+        return normals
+
+
+def polygonAvgNormals(coords, elems, weights='angle',
+                      atnodes=True, treshold=None):
+    """Compute averaged normals at the nodes of a polygon Mesh.
+
+    Parameters
+    ----------
+    coords: float :term:`array_like` (ncoords, 3)
+        Array with the coordinates of the nodes
+    elems: int :term:`array_like` (nelems, nplex, 3)
+        Definitions of the polygons in terms of the nodes. All polygons
+        should have the same plexitude.
+    weights: float :term:`array_like` | 'angle' | None
+        Weights to apply to the polygon normals at a node during averaging.
+        The default 'angle' will weigh the contribution of the polygons
+        by the angle their edges make at the node. Custom values should be
+        an array with shape (nelems, nplex). Specifying None will result
+        in giving the same weight to all normals.
+    atnodes: bool, optional
+        If True (default), unique averaged normals at the nodes are returned.
+        If False, the averaged normals are returned for each node of each
+        polygon. This is mainly intended for rendering purposes.
+    treshold: float, optional
+        Only used with ``atnodes=False``. If provided, element vertex normals
+        making an angle with the averaged normal having a cosinus smaller than
+        treshold, will be returned as the original normal. This allows for
+        rendering feature edges.
+
+    Returns
+    -------
+    normals: float array
+        (ncoords, 3)
+        The unit normals at the nodes, obtained by (weighted) averaging
+        the normals on the polygons attached to that node. The default
+        ``atnodes=True`` returns an array with shape (ncoords, 3). With
+        ``atnodes=False``, an array with shape (nelems, nplex, 3) is
+        returned.
+
+    Examples
+    --------
+    This example is the surface of a unit cube. The square faces are divided
+    into triangles by a single diagonal. Notice that the overage normals
+    come out nicely symmetric, despite the triangle layout not being
+    symmetric: only node 0 and 6 have diagonals in all three planes.
+    This is thanks to the use of weights equal to the angle between the
+    facet edges.
+
+    >>> from pyformex.simple import Cube
+    >>> M = Cube().convert('tri3-u')
+    >>> print(polygonAvgNormals(M.coords, M.elems))
+    [[-0.58 -0.58 -0.58]
+     [ 0.58 -0.58 -0.58]
+     [ 0.58  0.58 -0.58]
+     [-0.58  0.58 -0.58]
+     [-0.58 -0.58  0.58]
+     [ 0.58 -0.58  0.58]
+     [ 0.58  0.58  0.58]
+     [-0.58  0.58  0.58]]
+
+    If we do not use any weights and simply average the normals on all
+    facets at the node, the results are not so symmetric:
+
+    >>> print(polygonAvgNormals(M.coords, M.elems, weights=None))
+    [[-0.58 -0.58 -0.58]
+     [ 0.82 -0.41 -0.41]
+     [ 0.41  0.41 -0.82]
+     [-0.41  0.82 -0.41]
+     [-0.41 -0.41  0.82]
+     [ 0.41 -0.82  0.41]
+     [ 0.58  0.58  0.58]
+     [-0.82  0.41  0.41]]
+    """
+    if weights=='angle':
+        normals, weights = polygonNormals(coords[elems], return_angles=True)
+    else:
+        normals = polygonNormals(coords[elems])
+    if not atnodes and treshold is not None:
+        # save normals for comparison
+        fnormals = normals
+    if weights is not None:
+        normals *= weights[..., np.newaxis]
     normals, cnt = at.nodalSum(normals, elems, coords.shape[0])
     # No need to take average, since we are going to normalize anyway
     normals = at.normalize(normals)
-    if not atNodes:
+    if not atnodes:
         normals = normals[elems]
+        if treshold is not None:
+            fnormals = at.normalize(fnormals.reshape(-1,3))
+            normals = normals.reshape(-1,3)
+            cosa = at.vectorPairCosAngle(normals, fnormals)
+            w = np.where(cosa<treshold)[0]
+            normals[w, :] = fnormals[w, :]
+            normals = normals.reshape(elems.shape[0], 3, 3)
     return normals
 
 
+# TODO: remove after 2022-06; deprecated 2021-12
+@utils.deprecated_by("geomtools.averageNormals", "geomtools.polygonAvgNormals")
+def averageNormals(coords, elems, atNodes=False, treshold=None):
+    return polygonAvgNormals(coords, elems, weights=None,
+                             atnodes=atNodes, treshold=treshold)
+
+
 # TODO: if there are internal angles ~180, we might split first
 # at these vertices. Though we could use fillBorder for those cases.
 def split_polygon(coords, faces):
@@ -1743,7 +1877,7 @@ def split_polygon(coords, faces):
     --------
     splitPolygon: splits sets of polygons with different plexitude
     """
-    from pyFormex.mesh import Mesh
+    from pyformex.mesh import Mesh
     if not isinstance(coords, Coords):
         coords = Coords(coords)
     if not isinstance(faces, Connectivity):
@@ -1848,12 +1982,12 @@ def triangleInCircle(x):
     >>> from pyformex.formex import Formex
     >>> X = Formex(Coords([1.,0.,0.])).rosette(3,120.)
     >>> print(X)
-    {[1.0,0.0,0.0], [-0.5,0.866025,0.0], [-0.5,-0.866025,0.0]}
+    {[1.0,0.0,0.0], [-0.5,0.8660254,0.0], [-0.5,-0.8660254,0.0]}
     >>> radius, center, normal = triangleInCircle(X.coords.reshape(-1,3,3))
     >>> print(radius)
-    [ 0.5]
+    [0.5]
     >>> print(center)
-    [[ 0. 0. 0.]]
+    [[0. 0. 0.]]
 
     """
     at.checkArray(x, shape=(-1, 3, 3))
@@ -2134,20 +2268,20 @@ def baryCoords(S, P):
     >>> S = Coords('.1.6.4').reshape(3,2,3)
     >>> P = Coords([[[0,0,0],[0.2,0.2,0],[0.5,0.5,0],[0.5,0.7,0]]])
     >>> baryCoords(S,P)
-    array([[[ 1. ,  0. ],
-            [ 0.8,  0.2],
-            [ 0.5,  0.5],
-            [ 0.5,  0.5]],
+    array([[[1. ,  0. ],
+            [0.8,  0.2],
+            [0.5,  0.5],
+            [0.5,  0.5]],
     <BLANKLINE>
-           [[ 0.5,  0.5],
-            [ 0.5,  0.5],
-            [ 0.5,  0.5],
-            [ 0.4,  0.6]],
+           [[0.5,  0.5],
+            [0.5,  0.5],
+            [0.5,  0.5],
+            [0.4,  0.6]],
     <BLANKLINE>
-           [[ 0. ,  1. ],
-            [ 0.2,  0.8],
-            [ 0.5,  0.5],
-            [ 0.7,  0.3]]])
+           [[0. ,  1. ],
+            [0.2,  0.8],
+            [0.5,  0.5],
+            [0.7,  0.3]]])
     >>> S1 = Coords('016').reshape(1,3,3)
     >>> baryCoords(S1,P)
     array([[[ 1. ,  0. ,  0. ],
