@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2021 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 2.6  (Mon Aug 23 15:13:50 CEST 2021)
+##  This file is part of pyFormex 3.0  (Mon Nov 22 14:32:59 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -74,8 +74,8 @@ class FileDialog(Dialog):
     compr: bool
         If True, the specified filters will be expanded to also include
         compressed files of the specified patterns. Compression algorithms
-        include 'gz' and 'bz2'. For example, a filter 'Python files (\*.py)'
-        would be changed to 'Python files (\*.py \*.py.gz \*.py.bz2)'.
+        include 'gz' and 'bz2'. For example, a filter 'Python files (\\*.py)'
+        would be changed to 'Python files (\\*.py \\*.py.gz \\*.py.bz2)'.
     auto_suffix: bool
         If True (default), new file names will automatically be changed
         to have an extension matching the current filter.
