@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2021 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 2.6  (Mon Aug 23 15:13:50 CEST 2021)
+##  This file is part of pyFormex 3.0  (Mon Nov 22 14:32:59 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -1725,6 +1725,14 @@ def draw(F, clear=None, **kargs):
       element index color mode. If the object has no such attribute, the
       object is drawn in no color mode.
 
+    Hey! What about nodal color? When drawing a :class:`Mesh`, it is possible
+    to draw with colors that are specified on the nodes instead of on
+    the elements. To do that, just expand the colors to the element nodes
+    as follows. ``M`` is a :class:`Mesh`, ncolors is an array containing
+    ``M.ncoords()`` colors or color indices::
+
+      draw(M, color=ncolors[M.elems])
+
     Element and vertex color modes are usually only used with a single object
     in the `F` parameter, because they require a matching set of colors.
     Though the color set will be automatically resized if not matching, the
@@ -2095,7 +2103,6 @@ def drawBbox(F, *, actor=None, color='black', **kargs):
     The drawn Annotation(s).
     """
     bb = F.bbox()
-    print(pf.cfg['geometry_menu/bbox'])
     if actor is None:
         actor = pf.cfg['geometry_menu/bbox']
     if actor == 'bbox':
@@ -2371,7 +2378,7 @@ def drawField(fld, comp=0, scale='RAINBOW', symmetric_scale=False,
     CLA = ColorLegend(CS, 256, CLAx, CLAy, CLAw, CLAh, scale=multiplier)
     drawActor(CLA)
     decorate(drawText(f"{fld.fldname} (1.e{-multiplier})",
-                      (20, 250), size=18, color='black'))
+                      (10, 260), size=18, color='black'))
     if fld.fldtype == 'node':
         draw(fld.geometry, color=cval[fld.geometry.elems], **kargs)
     else:
