@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2021 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 2.6  (Mon Aug 23 15:13:50 CEST 2021)
+##  This file is part of pyFormex 3.0  (Mon Nov 22 14:32:59 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -40,7 +40,7 @@ from pyformex import process
 from pyformex import utils
 from pyformex import software
 
-# If we get here, either PySide2, PySide, PyQt5 or PyQt4 are imported
+# If we get here, either PySide2 or PyQt5 are imported
 # Check for OpenGL
 if not pf.sphinx:
     if pf.options.mgl:
@@ -888,23 +888,6 @@ class Gui(QtWidgets.QMainWindow):
         e.ignore()
 
 
-    # TODO: check if this is still needed !
-    def XPos(self):
-        """Get the main window position from the xwininfo command.
-
-        The Qt position does not get updated when
-        changing the window size from the left.
-        This substitute function will find the correct position from
-        the xwininfo command output.
-        """
-        res = xwininfo(windowid=self.winId())
-        ax, ay, rx, ry = [int(res[key]) for key in [
-            'Absolute upper-left X', 'Absolute upper-left Y',
-            'Relative upper-left X', 'Relative upper-left Y',
-            ]]
-        return ax-rx, ay-ry
-
-
     def XGeometry(self, border=True):
         """Get the main window position and size.
 
@@ -933,11 +916,6 @@ class Gui(QtWidgets.QMainWindow):
 
         """
         pf.debug('Store current settings', pf.DEBUG.CONFIG)
-        # TODO: check if this is still needed
-        # FIX QT4 BUG
-        # Make sure QT4 has position right
-        self.move(*self.XPos())
-
         # store the history and main window size/pos
         pf.prefcfg['gui/scripthistory'] = pf.GUI.scripthistory.files
         pf.prefcfg['gui/apphistory'] = pf.GUI.apphistory.files
@@ -1365,7 +1343,7 @@ def showSplash():
         pf.debug('Loading splash %s' % splash_path, pf.DEBUG.GUI)
         splashimage = QPixmap(splash_path)
         splash = QtWidgets.QSplashScreen(splashimage)
-        splash.setWindowFlags(QtCore.Qt.WindowStaysOnTopHint|QtCore.Qt.SplashScreen)
+        #splash.setWindowFlags(QtCore.Qt.WindowStaysOnTopHint|QtCore.Qt.SplashScreen)
         splash.setFont(QtGui.QFont("Helvetica", 20))
         splash.showMessage(pf.Version(), QtCore.Qt.AlignHCenter|QtCore.Qt.AlignTop, QtCore.Qt.red)
         splash.show()
@@ -1685,6 +1663,11 @@ def createDatabases():
     pf.GS = pf.GUI.selection['geometry']
 
 
+    #print(f"EXCEPTHOOK builtin {id(sys.__excepthook__)}")
+    #print(f"EXCEPTHOOK active  {id(sys.excepthook)}")
+
+
+
 easter_egg=''
 
 def runGUI():
