@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2021 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 2.6  (Mon Aug 23 15:13:50 CEST 2021)
+##  This file is part of pyFormex 3.0  (Mon Nov 22 14:32:59 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -197,6 +197,8 @@ class QtCanvas(QtOpenGL.QGLWidget, canvas.Canvas):
     positional arguments are passed to the QtOpenGL.QGLWidget constructor,
     while the keyword arguments are passed to the canvas.Canvas constructor.
     """
+    _exclude_members_ = ['Communicate']
+
     cursor_shape = {'default': QtCore.Qt.ArrowCursor,
                      'pick': QtCore.Qt.CrossCursor,
                      'draw': QtCore.Qt.CrossCursor,
@@ -369,7 +371,8 @@ class QtCanvas(QtOpenGL.QGLWidget, canvas.Canvas):
         self.makeCurrent()
         wc, hc = pf.canvas.getSize()
         w, h = self.saneSize(w, h)
-        vcanvas = QtOpenGL.QGLFramebufferObject(w, h)
+        #vcanvas = QtOpenGL.QGLFramebufferObject(w, h)
+        vcanvas = QtGui.QOpenGLFramebufferObject(w, h)
         vcanvas.bind()
         self.resize(w, h)
         self.display()
