@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2021 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 2.6  (Mon Aug 23 15:13:50 CEST 2021)
+##  This file is part of pyFormex 3.0  (Mon Nov 22 14:32:59 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -110,9 +110,9 @@ warn_select_changed = "The select and cselect methods have changed for Mesh type
 warn_radio_enabler = "A 'radio' type input item can currently not be used as an enabler for other input fields."
 
 trisurface_remesh = "TriSurface.remesh now uses the instant-meshes program. If you don't have it, you can install if from the pyformex/extra/instant directory or from the Help menu"
+trisurface_edgeangles = "TriSurface.cosAngles and TriSurface.edgeSignedAngles are deprecated. TriSurface.edgeAngles now returns the signed angles previously returned by TriSurface.edgeSignedAngles."
 
 warn_viewport_linking = "Linking viewports is an experimental feature and is not fully functional yet."
-warn_vmtk_includeprop = "includeprop %s are in the property set %s. Remesh will not have any effect."
 warn_writevtp_notclean = "Mesh is not clean: vtk will alter the nodes. To clean: mesh.fuse().compact().renumber()"
 warn_writevtp_duplicates = "Mesh contains duplicate elements. This may give problems in VTK / ParaView.\n Duplicates: %s "
 warn_writevtp_shape = "The number of array cells should be equal to the number of elements"
@@ -122,8 +122,6 @@ warn_vectorRotation_deprecated = "vectorRotation is deprecated. Use rotMatrix2 i
 warn_rotationAnglesFromMatrix_deprecated = "rotationAnglesFromMatrix is deprecated. Use cardanAngles instead."
 
 error_widgets_enableitem = "Error in a dialog item enabler. This should not happen! Please file a bug report."
-error_no_gts_bin = "I am missing the gts binary programs on your system.\nTherefore, some surface operations will not be available or fail.\n\nOn Debian, you can install the missing programs with `apt-get install libgts-bin`.\n"
-error_no_gts_extra = "I am missing the gts binary programs on your system.\nTherefore, some surface operations will not be available or fail.\n\nOn Debian, you can install the missing programs with `apt-get install pyformex-extra`.\n"
 
 depr_mesh_getlowerentities_unique = "The use of the unique argument in getLowerEntities is deprecated. Use \n sel = self.elType().getEntities(level) \n lower = self.elems.insertLevel(sel)[1] "
 depr_pathextension = "patchextension is deprecated. Use border().extrude() instead."
