@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2021 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 2.6  (Mon Aug 23 15:13:50 CEST 2021)
+##  This file is part of pyFormex 3.0  (Mon Nov 22 14:32:59 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -183,6 +183,7 @@ class CanvasSettings(Dict):
     - bkcolor: the default backface color
     - colormap: the default color map to be used if color is an index
     - bklormap: the default color map to be used if bkcolor is an index
+    - textcolor: the default color for text drawing
     - smooth: boolean (smooth/flat shading)
     - lighting: boolean (lights on/off)
     - culling: boolean
@@ -292,7 +293,7 @@ class CanvasSettings(Dict):
         for k, v in dict.items():
             try:
                 if k in ['bgcolor', 'fgcolor', 'bkcolor', 'slcolor',
-                          'colormap', 'bkcolormap']:
+                          'colormap', 'bkcolormap', 'textcolor']:
                     if v is not None:
                         v = saneColor(v)
                 elif k in ['bgimage']:
