@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2021 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 2.6  (Mon Aug 23 15:13:50 CEST 2021)
+##  This file is part of pyFormex 3.0  (Mon Nov 22 14:32:59 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -125,11 +125,11 @@ class ColorLegend(Actor):
     guide to decode the colors. The ColorLegend decoration provides
     such a color legend. This class only provides the visual details of
     the scale. The conversion of the numerical values to the matching colors
-    is provided by the :class:`colorscale.ColorScale` class.
+    is provided by the :class:`~gui.colorscale.ColorScale` class.
 
     Parameters:
 
-    - `colorscale`: a :class:`colorscale.ColorScale` instance providing
+    - `colorscale`: a :class:`~gui.colorscale.ColorScale` instance providing
       conversion between numerical values and colors
     - `ncolors`: int: the number of different colors to use.
     - `x,y,w,h`: four integers specifying the position and size of the
@@ -150,7 +150,7 @@ class ColorLegend(Actor):
       If < 0 (default), a default number of labels is shown.
     - `size`: font size to be used for the labels
     - `font`: font to be used for the labels. It can be a
-      :class:`textext.FontTexture` or a string with the path to a monospace
+      :class:`~opengl.textext.FontTexture` or a string with the path to a monospace
       .ttf font. If unspecified, the default font is used.
     - `dec`: int: number of decimals to be used in the labels
     - `scale`: int: exponent of 10 for the scaling factor of the label values.
@@ -299,7 +299,7 @@ def Grid(nx=(1, 1, 1), ox=(0.0, 0.0, 0.0), dx=(1.0, 1.0, 1.0),
     -------
     :class:`List`
         A List with up to two Meshes: the planes and the lines. The Meshes
-        come with the following :class:`Attributes` set:
+        come with the following :class:`~attributes.Attributes` set:
 
         - name: the provided name with '_planes_' or '_lines_' appended.
         - color: the provided plane or line color
