@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2021 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 2.6  (Mon Aug 23 15:13:50 CEST 2021)
+##  This file is part of pyFormex 3.0  (Mon Nov 22 14:32:59 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -750,8 +750,9 @@ class Actor(BaseActor):
         """Return averaged normals at the vertices"""
         if self._avgnormals is None:
             tol = pf.cfg['render/avgnormaltreshold']
-            self._avgnormals = gt.averageNormals(self.coords, self.elems, False, tol).astype(float32)
-            #self._avgnormals = gt.averageNormals(self.coords, self._faces, False, tol).astype(float32)
+            self._avgnormals = gt.polygonAvgNormals(
+                self.coords, self.elems,
+                atnodes=False, treshold=tol).astype(float32)
             #print(f"COMPUTED AVGNORMALS for {self.name}: {self._avgnormals.shape}")
             #print(self._avgnormals)
         return self._avgnormals
