@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2021 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 2.6  (Mon Aug 23 15:13:50 CEST 2021)
+##  This file is part of pyFormex 3.0  (Mon Nov 22 14:32:59 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -300,6 +300,10 @@ class Text(Actor):
         if rotate is not None:
             grid = grid.rotate(rotate)
 
+        # Set default color if not specified
+        if 'color' not in kargs:
+            kargs['color'] = pf.cfg['canvas/textcolor']
+
         # create the actor for the first line
         l = lt[0]
         g = grid.select(range(l)).align(alignment, pos)
