@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2021 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 2.6  (Mon Aug 23 15:13:50 CEST 2021)
+##  This file is part of pyFormex 3.0  (Mon Nov 22 14:32:59 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -264,9 +264,8 @@ def createParser():
         "--bindings",
         action="store",
         default=None,
-        help="Override the configuration setting for the Qt5/4 bindings. "
-        "Available bindings are 'pyside2' or 'pyqt5' for Qt5 and "
-        "'pyside' or 'pyqt4' for Qt4. "
+        help="Override the configuration setting for the Qt5 bindings. "
+        "Available bindings are 'pyside2' or 'pyqt5'."
         "A value 'any' may be given to let pyFormex find out which "
         "bindings are available and use one of these.",
     )
