@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2021 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 2.6  (Mon Aug 23 15:13:50 CEST 2021)
+##  This file is part of pyFormex 3.0  (Mon Nov 22 14:32:59 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -37,7 +37,6 @@ import pyformex as pf
 from pyformex import utils
 from pyformex import fileread
 from pyformex import filewrite
-from pyformex import saveload
 from pyformex import simple
 
 from pyformex.geomfile import GeometryFile
@@ -238,99 +237,6 @@ def set_selection(data='geometry'):
 
 ##################### read and write ##########################
 
-# TODO: this should be moved to core (in script?)
-def readGeometry(filename, filetype=None, target=None, **kargs):
-    """Read geometry from a stored file.
-
-    This is a wrapper function over several other functions specialized
-    for some file type. Some file types require the existence of more
-    than one file, may need to write intermediate files, or may call
-    external programs.
-
-    The return value is a dictionary with named geometry objects read from
-    the file.
-
-    If no filetype is given, it is derived from the filename extension.
-    Currently the following file types can be handled.
-
-    'pgf': pyFormex Geometry File. This is the native pyFormex geometry
-        file format. It can store multiple parts of different type, together
-        with their name.
-    'surface': a global filetype for any of the following surface formats:
-        'stl', 'gts', 'off', 'neu'
-    'obj': .obj files (3- and 4-plex meshes only, no fancy things)
-    'inp': Abaqus and CalculiX input format
-    'tetgen':
-    """
-    filename = Path(filename)
-    res = {}
-    compr = None
-    if filetype is None:
-        filetype, compr = filename.ftype_compr()
-
-    print("Reading file %s of type '%s' (%s)" % (filename, filetype, compr))
-
-    if filetype == 'pgf':
-        res = readGeomFile(filename)
-
-    elif filetype == 'pzf':
-        res = saveload.loadPZF(filename)
-
-    elif filetype == 'off' and target != 'surface':
-        coords, faces, edges = fileread.readOFF(filename)
-        coords = Coords(coords)
-        for elems in [faces, edges]:
-            if elems.shape[0] > 0:
-                name = next(utils.autoName(Mesh))
-                els = Elems(elems, eltype=None)
-                mesh = Mesh(coords, els)
-                res[f"{name}-{mesh.elems.eltype}"] = mesh
-
-    elif filetype == 'neu' and target != 'surface':
-        mesh = fileread.readNEU(filename)
-        res[f"{filename.stem}"] = mesh
-
-    elif filetype in ['obj', 'ply'] and target != 'surface':
-        reader = {'obj':fileread.readOBJ,
-                  'ply':fileread.readPLY}[filetype]
-        coords, elems = reader(filename, mplex=kargs.get('mplex',None))
-        coords = Coords(coords)
-        name = next(utils.autoName(Mesh))
-        for nplex in elems:
-            if nplex <= 4:
-                els = Elems(elems[nplex], eltype=None)
-                mesh = Mesh(coords, els)
-                res[f"{name}-{mesh.elems.eltype}"] = mesh
-            else:
-                pf.verbose(1, f"Skipping {elems[nplex].shape[0]} elements of plexitude {nplex}")
-
-    # Beware! this should come after 'obj', otherwise
-    # non-triangles in the .obj file will be skipped
-    elif filetype in utils.fileTypes('surface'):
-        S = TriSurface.read(filename)
-        name = next(utils.autoName(TriSurface))
-        res = {name: S}
-
-    elif filetype == 'inp':
-        parts = fileread.readINP(filename)
-        color_by_part = len(parts) > 1
-        j = 0
-        for name in parts:
-            for i, mesh in enumerate(parts[name].meshes()):
-                p = j if color_by_part else i
-                print("Color %s" % p)
-                res["%s-%s" % (name, i)] = mesh.setProp(p)
-            j += 1
-
-    elif filetype in utils.fileTypes('tetgen'):
-        from pyformex.plugins import tetgen
-        res = tetgen.readTetgen(filename)
-
-    else:
-        error("Can not import from file %s of type %s" % (filename, filetype))
-
-    return res
-
 
 def importGeometry(select=True, draw=True, ftype=None, compr=False, target=None):
     """Read geometry from file.
@@ -454,87 +360,6 @@ def readInp(fn=None):
         return
 
 
-def writeGeometry(obj, filename, ftype=None, compr=False, **kargs):
-    """Write the geometry items in objdict to the specified file.
-
-    Returns the number of objects written.
-    """
-    nobj = 0
-    filename = Path(filename)
-    writer = kargs.pop('writer', None)
-    if writer == 'meshio':
-        from pyformex.plugins.mesh_io import writeMesh
-        for name in obj:
-            writeMesh(filename, obj[name])
-            return 1
-
-    if ftype is None:
-        ftype, compr = filename.ftype_compr()
-
-    if ftype == 'pzf':
-        res = ask("Include the current camera/canvas settings?", ["No", "Camera only", "Full Canvas Layout"])
-        if res.startswith("Camera"):
-            obj['_camera'] = True
-        elif res.startswith("Full"):
-            obj['_canvas'] = True
-
-    print("Writing file of type %s" % ftype)
-
-    if ftype == 'pgf':
-        sep = '' if kargs['mode']=='binary' else ' '
-        shortlines = kargs['mode'].startswith('short')
-        nobj = writeGeomFile(filename, obj, sep=sep, shortlines=shortlines)
-
-    elif ftype == 'pzf':
-        saveload.savePZF(filename, **obj)
-        nobj = len(obj)
-
-    elif ftype in ('obj', 'off', 'ply', 'neu'):
-        for name in obj: # There is only one and it's a Mesh
-            mesh = obj[name]
-            if ftype == 'obj':
-                filewrite.writeOBJ(filename, mesh)
-            elif ftype == 'off':
-                filewrite.writeOFF(filename, mesh)
-            elif ftype == 'neu':
-                filewrite.writeNEU(filename, mesh)
-            elif ftype == 'ply':
-                filewrite.writePLY(filename, mesh.coords,
-                                   {mesh.nplex():mesh.elems})
-            nobj += 1
-
-    elif ftype == 'stl':
-        if kargs['binary']:
-            from pyformex import colors
-            ftype = 'stlb'
-            color = colors.RGBAcolor(kargs['color'], kargs['alpha'])
-            print(f"Also saving color {color}")
-        else:
-            color = None
-        for name in obj:  # There is only one and it's a TriSurface
-            S = obj[name]
-            S.write(filename, ftype, color=color)
-            nobj += 1
-
-    elif ftype in ('gts', 'neu', 'smesh', 'vtp', 'vtk'):
-        for name in obj: # There is only one and it's a TriSurface
-            S = obj[name]
-            S.write(filename, ftype)
-            nobj += 1
-
-    elif ftype == 'inp':
-        from pyformex.plugins.fe_abq import exportMesh
-        for name in obj: # There is only one and it's a Mesh
-            M = obj[name]
-            exportMesh(filename, M, kargs['ELTYPE'])
-            nobj += 1
-
-    else:
-        error("Don't know how to export in '%s' format" % ftype)
-
-    return nobj
-
-
 def exportGeometry(ftype, single=False, compr=True, allowed=None, **kargs):
     """Write geometry to file.
 
@@ -556,16 +381,43 @@ def exportGeometry(ftype, single=False, compr=True, allowed=None, **kargs):
         db = selection
     if not db.checkOrAsk(single=single, allowed=allowed):
         return
+    print(f"Exporting {list(db.keys())}")
+    def changeSelection(buttons):
+        print(buttons)
+        item = buttons.parent
+        db.ask(single=single, allowed=allowed)
+        item.setValue(len(db.names))
+    if ftype=='pzf':
+        kargs['extra'].append(
+            _I('_select', len(db.names), itemtype='info',
+               text=f"Number of selected objects",
+               buttons=[('Change selection', changeSelection)]))
 
     cur = pf.cfg['workdir']
     res = askFile(cur=cur, filter=ftype, compr=compr, **kargs)
     if res:
+
+        # convert widget data to writeGeometry parameters
+        if ftype == 'pzf':
+            res.pop('_select')
+            env = res.pop('environ')
+            if env == 'Camera':
+                obj['_camera'] = True
+            elif env == 'Canvas':
+                obj['_canvas'] = True
+
         fn = res.pop('filename')
         print(f"Writing geometry file {fn}")
-        res = writeGeometry(db.odict(), fn, compr=compr, **res)
-        print(f"Contents: {res}")
+        nobj = writeGeometry(fn, db.odict(), compr=compr, **res)
+        print(f"Objects written: {nobj}")
 
 
+def exportPzf():
+    exportGeometry('pzf', single=False, extra=[
+        _I('environ', choices=['None', 'Camera', 'Canvas'],
+           itemtype='hradio', text='Add environment',),
+    ])
+
 def exportPgf():
     kargs = {
         'compr': True,
@@ -574,9 +426,6 @@ def exportPgf():
     }
     exportGeometry('pgf', single=False, **kargs)
 
-def exportPzf():
-    exportGeometry('pzf', single=False)
-
 def exportOff():
     exportGeometry('off', single=True, allowed=Mesh)
 
@@ -591,9 +440,9 @@ def exportNeu():
 
 def exportStl():
     exportGeometry('stl', single=True, allowed=TriSurface, extra=[
-            _I('binary', True),
-            _I('color', 'red', itemtype='color'),
-            _I('alpha', 0.5),
+        _I('binary', True),
+        _I('color', 'red', itemtype='color'),
+        _I('alpha', 0.5),
     ])
 
 def exportGts():
@@ -605,7 +454,7 @@ def exportSurf():
 
 def exportInp():
     exportGeometry(['inp'], single=True, allowed=Mesh, extra=[
-        _I('ELTYPE', 'ELTYPE', text='Abaqus element type (required)'),
+        _I('eltype', 'ELTYPE', text='Abaqus element type (required)'),
     ])
 
 def exportMesh():
@@ -1049,6 +898,8 @@ def createCube():
 
 
 def createCylinder():
+    # TODO: we should reverse the surface if it is Mesh/TriSurface
+    # or better: do it in simple.sphere
     _name = 'createCylinder'
     _data = _name + '_data'
     res = askItems(caption=_name, store=_data, items=[
