@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2021 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 2.6  (Mon Aug 23 15:13:50 CEST 2021)
+##  This file is part of pyFormex 3.0  (Mon Nov 22 14:32:59 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -44,9 +44,6 @@ from pyformex.gui import QtGui, QImage
 
 QColor = QtGui.QColor
 
-if pf.gui.bindings == 'pyside2':
-    QImage.numBytes = QImage.byteCount
-
 ####################################################################
 # Import/export images using PIL
 
@@ -245,10 +242,11 @@ def qimage2numpy(image, resize=(0, 0), order='RGBA', flip=True, indexed=None):
                           QImage.Format_ARGB32,
                           QImage.Format_RGB32):
         buf = image.bits()
-        if pf.gui.bindings == 'pyqt4':
-            buf = buf.asstring(image.numBytes())
+        # TODO: is this needed??
+        if pf.gui.bindings == 'pyqt5':
+            buf = buf.asstring(image.byteCount())
         ar = np.frombuffer(buf, dtype='ubyte',
-                           count=image.numBytes()).reshape(h, w, 4)
+                           count=image.byteCount()).reshape(h, w, 4)
         idx = ['BGRA'.index(c) for c in order]
         ar = ar[..., idx]
         ct = None
@@ -259,8 +257,9 @@ def qimage2numpy(image, resize=(0, 0), order='RGBA', flip=True, indexed=None):
         idx = ['BGRA'.index(c) for c in order]
         ct = ct[..., idx]
         buf = image.bits()
-        if pf.gui.bindings == 'pyqt4':
-            buf = buf.asstring(image.numBytes())
+        # TODO: is this needed??
+        if pf.gui.bindings == 'pyqt5':
+            buf = buf.asstring(image.byteCount())
         ar = np.frombuffer(buf, dtype=np.uint8)
         if ar.size % h == 0:
             ar = ar.reshape(h, -1)
