@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2021 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 2.6  (Mon Aug 23 15:13:50 CEST 2021)
+##  This file is part of pyFormex 3.0  (Mon Nov 22 14:32:59 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -199,11 +199,17 @@ SelectableStatsValues = {
     'Curvature': (TriSurface.curvature, False),
 }
 
-# Options for curvature
-CurvatureValues = (
-    'Gaussian curvature', 'Mean curvature', 'Shape index',
-    'Curvedness', 'First principal curvature', 'Second principal curvature',
-)
+# Drawable options for curvature.
+CurvatureValues = [
+    'Shape index S',
+    'Curvedness C',
+    'Gaussian curvature K',
+    'Mean curvature H',
+    'First principal curvature k1',
+    'Second principal curvature k2',
+    'First principal direction d1',
+    'Second principal direction d2',
+]
 
 
 def showHistogram(key, val, cumulative):
@@ -224,12 +230,18 @@ def showStatistics(key=None, domain=True, dist=False, cumdist=False, clip=None,
         func, onEdges = SelectableStatsValues[key]
         kargs = {}
         if key == 'Curvature':
-            kargs['neighbours'] = _stat_dia.results['neighbours']
+            kargs['neigh'] = _stat_dia.results['neigh']
         val = func(S, **kargs)
+        as_vectors = False
         if key == 'Curvature':
-            ind = CurvatureValues.index(_stat_dia.results['curval'])
-            val = val[ind]
-            val = val[S.elems]
+            key = _stat_dia.results['curval']
+            ind = key.split()[-1]
+            if ind in ['d1', 'd2']:
+                val = val['d1'], val['d2']
+                as_vectors=True
+            else:
+                val = val[ind]
+                val = val[S.elems]
 
         # !! THIS SHOULD BE IMPLEMENTED AS A GENERAL VALUE CLIPPER
         # !! e.g popping up when clicking the legend
@@ -264,8 +276,16 @@ Most likely because 'python-scipy' is not installed on your system.""")
 
         if domain:
             clear()
-            lights(False)
-            showSurfaceValue(S, key, val, onEdges)
+            if as_vectors:
+                # TODO: this can become a drawTensor function
+                siz =0.5*S.edgeLengths().mean()
+                drawVectors(S.coords, val[0], size=siz, color=red)
+                drawVectors(S.coords, val[1], size=siz, color=darkgreen)
+                lights(True)
+                draw(S, mode='smooth')
+            else:
+                lights(False)
+                showSurfaceValue(S, key, val, onEdges)
         if dist:
             showHistogram(key, val, cumulative=False)
         if cumdist:
@@ -320,7 +340,7 @@ def showStatisticsDialog():
         caption='Surface Statistics', items=[
             _C('', [
                 _I('Value', itemtype='vradio', choices=keys),
-                _I('neighbours', text='Curvature Neighbourhood', value=1),
+                _I('neigh', text='Curvature Neighbourhood', value=1),
                 _I('curval', text='Curvature Value', itemtype='vradio', choices=CurvatureValues),
             ]),
             _C('', [
@@ -351,7 +371,7 @@ def showSurfaceValue(S, txt, val, onEdges):
         M = S
     fld = Field(M, 'elemc', val)
     drawField(fld)
-    drawText(txt, (10, 240), size=18)
+    #drawText(txt, (10, 240), size=18)
 
 
 def partitionByAngle():
@@ -380,13 +400,15 @@ def showFeatureEdges():
         selection.draw()
         res  = askItems([
             _I('angle', 60.),
+            _I('minangle', -60.),
             _I('ontop', False),
             ])
         pf.app.processEvents()
         if res:
-            p = S.featureEdges(angle=res['angle'])
+            ontop = res.pop('ontop')
+            p = S.featureEdges(**res)
             M = Mesh(S.coords, S.edges[p])
-            draw(M, color='red', linewidth=3, bbox='last', nolight=True, ontop=res['ontop'])
+            draw(M, color='red', linewidth=3, bbox='last', nolight=True, ontop=ontop)
 
 
 #############################################################################
@@ -916,9 +938,11 @@ def remesh():
     next(nseq)
     newname = next(nseq)
     methods = ['acvd']
-    for m in ['instant-meshes', 'vmtk']:
+    for m in ['instant-meshes']:
         if utils.External.has(m):
             methods.append(m)
+    # use instant-meshes as default if available
+    method = 'instant-meshes' if 'instant-meshes' in methods else methods[0]
     vertices = S.ncoords()
     faces = S.nelems()
     edglen = S.edgeLengths()
@@ -927,12 +951,9 @@ def remesh():
     boundaries = not S.isClosedManifold()
     crease = 90
     intrinsic = False
-    # vmtk
-    edgelength = S.edgeMesh().lengths().mean()
-    area = S.areas().mean()
     res = askItems(caption=_name, store=_data, items=[
         _I('name', newname),
-        _I('method', choices=methods),
+        _I('method', method, choices=methods),
         _G('a', text='Parameters for acvd', items=[
             _I('npoints', vertices),
             _I('ndiv', 3),
@@ -950,21 +971,12 @@ def remesh():
             _I('intrinsic', intrinsic),
             _I('crease', crease),
             ]),
-        _G('v', text='Parameters for vmtk', items=[
-            _I('elementsizemode', choices=['edgelength', 'area', 'areaarray'],
-               itemtype='combo', value='edgelength'),
-            _I('edgelength', edgelength),
-            _I('area', area),
-            ]),
     ], enablers=[
         ('method', 'acvd', 'a'),
         ('method', 'instant-meshes', 'i'),
-        ('method', 'vmtk', 'v'),
         ('resolution', 'vertices', 'vertices'),
         ('resolution', 'faces', 'faces'),
         ('resolution', 'scale', 'scale'),
-        ('elementsizemode', 'edgelength', 'edgelength'),
-        ('elementsizemode', 'area', 'area'),
         ]
     )
 
@@ -1049,45 +1061,6 @@ def tri2quad_auto(suffix='_quad4'):
     pf.GUI.selection['geometry'].draw()
 
 
-##################  Operations using vmtk  ##################
-
-#
-# TODO This should be moved to vmtk_itf module,
-# a function writing a message could be kept here
-# OR, test whether we have vmtk, and act accordingly
-#
-
-def remesh_vmtk():
-    # USES VMTK: NEEDS TO IMPORT!
-    from pyformex.plugins import vmtk_itf
-    S = selection.check(single=True)
-    if S:
-        selection.remember()
-        S = S.remesh_vmtk()
-        selection.changeValues([S])
-        selection.drawChanges()
-
-def centerline():
-    # USES VMTK: NEEDS TO IMPORT!
-    from pyformex.plugins import vmtk_itf
-    S = selection.check(single=True)
-    if S:
-        from pyformex.plugins.vmtk_itf import install_trisurface_methods
-        install_trisurface_methods()
-
-        res = askItems([_I('Include endpoints', True),
-                    _I('Group centerlines', False),
-                    ], caption='Centerline settings')
-
-        if res:
-            eps = res['Include endpoints']
-            grp = res['Group centerlines']
-
-        CL, CLdata = S.centerline(endpoints=eps, groupcl=grp)
-        export({'centerline': CL})
-        export({'centerline_data': CLdata})
-        draw(CL, color=red, ontop=True, nolight=True)
-
 
 ################### menu #################
 
@@ -1131,10 +1104,6 @@ def create_menu(before='help'):
             ('&Quality remesh surface to tri3 or quad4 mesh', remesh),
             ('&Auto-convert multiple surfaces to quad4', tri2quad_auto),
         ]),
-        ('&VMTK functions', [
-            ('&Quality remesh surface', remesh_vmtk),
-            ("&Compute centerline", centerline),
-        ]),
         #        ("&Show volume model",show_volume),
         # ("&Print Nodal Coordinates",show_nodes),
         # ("&Convert STL file to OFF file",convert_stl_to_off),
@@ -1150,7 +1119,6 @@ def create_menu(before='help'):
     # Enable menus needing optional external software
     m['&GTS functions'].setEnabled(utils.External.has('gts-extra') != '')
     m['&Instant Meshes'].setEnabled(utils.External.has('instant-meshes') != '')
-    m['&VMTK functions'].setEnabled(utils.External.has('vmtk') != '')
     return m
 
 
