@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2021 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 2.6  (Mon Aug 23 15:13:50 CEST 2021)
+##  This file is part of pyFormex 3.0  (Mon Nov 22 14:32:59 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -50,31 +50,10 @@ from pyformex.coords import Coords
 from pyformex.varray import Varray
 from pyformex.plugins.curve import PolyLine
 
-def delete_modules(modules):
-    """Remove modules by name"""
-    for module in modules:
-        try:
-            del sys.modules[module]
-        except Exception:
-            pass
 
-
-# Try to import stock vtk
-utils.Module.require('vtk')
-VTK_VERSION = utils.Module.has('vtk')
-
-if int(VTK_VERSION.split('.')[0]) == 6 and pf.options.vtk != 'standard':
-
-    # Use the vtk version from pyformex.vtk_light
-    import vtk_light.load
-    import vtk_light.util
-    sys.modules['vtk'] = vtk = vtk_light.load
-    sys.modules['vtk.util'] = vtk.util = vtk_light.util
-
-else:
-
-    # Use the standard version (vtk 5, or --vtk=standard option)
-    import vtk
+# Make sure we have vtk
+utils.Module.require('vtk', '>= 7.0')
+import vtk
 
 from vtk.util.numpy_support import numpy_to_vtk, vtk_to_numpy, get_numpy_array_type, get_vtk_array_type
 
@@ -129,36 +108,8 @@ VTUtypes = {
     'hex8': vtk.VTK_HEXAHEDRON,
     }
 
-def SetInput(vtkobj, data):
-    """ Select SetInput method according to the vtk version. After version 5
-    vtkObjects need the input through SetInputData, before version 6 it was called
-    SetInput.
-
-    Note that this applies only to vtkAlgorithm instances. In all other case
-    the use of SetInput is kept. For these cases this function must not be used.
-    """
-
-    if vtk.VTK_MAJOR_VERSION <= 5:
-        vtkobj.SetInput(data)
-    else:
-        vtkobj.SetInputData(data)
-    return vtkobj
-
-
-#FI to check when it fails and with which versions
-def AddInput(vtkobj, data):
-    """ Select AddInput method according to the vtk version. After version 5
-    vtkObjects need the input through AddInputData, before version 6 it was called
-    AddInput.
-    """
-
-    if vtk.VTK_MAJOR_VERSION <= 5:
-        vtkobj.AddInput(data)
-    else:
-        vtkobj.AddInputData(data)
-    return vtkobj
-
 
+# This docstring is extremely confusing
 def Update(vtkobj):
     """ Select Update method according to the vtk version. After version 5
     Update is not needed for vtkObjects, only to vtkFilter and vtkAlgortythm classes.
@@ -166,11 +117,8 @@ def Update(vtkobj):
     Note that this applies only to vtkAlgorithm instances. In all other case
     the use of Update is kept. For this cases this function must not be used.
     """
-
-    if vtk.VTK_MAJOR_VERSION <= 5:
-        vtkobj.Update()
-    if vtk.VTK_MAJOR_VERSION >= 6 and isinstance(vtkobj, vtk.vtkAlgorithm):
-        vtkobj.Update()
+    if isinstance(vtkobj, vtk.vtkAlgorithm):
+       vtkobj.Update()
     return vtkobj
 
 
@@ -225,7 +173,7 @@ def cleanVPD(vpd):
     Returns the cleaned vtkPolyData.
     """
     cleaner = vtk.vtkCleanPolyData()
-    cleaner = SetInput(cleaner, vpd)
+    cleaner.SetInputData(vpd)
     cleaner = Update(cleaner)
     return  cleaner.GetOutput()
 
@@ -385,7 +333,7 @@ def convertVPD2Triangles(vpd):
     Returns
     """
     triangles = vtk.vtkTriangleFilter()
-    triangles = SetInput(triangles, vpd)
+    triangles.SetInputData(vpd)
     triangles = Update(triangles)
     return triangles.GetOutput()
 
@@ -599,7 +547,7 @@ def writeVTP(fn, mesh, fielddata={}, celldata={}, pointdata={}, checkMesh=True,
         vtkdata.SetName(k)
         lvtk.GetPointData().AddArray(vtkdata)
     #~ print(('************lvtk', lvtk))
-    writer = SetInput(writer, lvtk)
+    writer.SetInputData(lvtk)
     writer.SetFileName(fn)
     writer.Write()
 
@@ -623,9 +571,10 @@ def writeVTPmany(fn, items):
         writer = vtk.vtkDataSetWriter()
         apd = vtk.vtkAppendFilter()
         vtkitems = [convert2VTU(M=m) for m in items]
-    [AddInput(apd, lvtk) for lvtk in vtkitems]
+    for lvtk in vtkitems:
+        apd.AddInputData(lvtk)
     vtkobj = apd.GetOutput()
-    writer = SetInput(writer, vtkobj)
+    writer.SetInputData(vtkobj)
     writer.SetFileName(fn)
     writer.Write()
 
@@ -710,7 +659,7 @@ def pointInsideObject(S, P, tol=0., check_surface=True):
     vps = convert2VPD(S, clean=False)
 
     enclosed_pts = vtk.vtkSelectEnclosedPoints()
-    enclosed_pts = SetInput(enclosed_pts, vpp)
+    enclosed_pts.SetInputData(vpp)
     enclosed_pts.SetTolerance(tol)
     # according to the documentation SetSurfaceData in VTK 7 is only
     # used in vtkSelectEnclosedPoints. A general function is not needed
@@ -741,7 +690,7 @@ def inside(surf, pts, tol='auto'):
     Returns an integer array with the indices of the points that are
     inside the surface.
 
-    See also :meth:`pyformex_gts.inside` for an equivalent and faster
+    See also :meth:`gts_itf.inside` for an equivalent and faster
     alternative.
     """
     if tol == 'auto':
@@ -901,7 +850,7 @@ def transform(source, trMat4x4):
     vtksource = convert2VPD(source)
     trMat4x4 = convertTransform4x4ToVtk(trMat4x4)
     transformFilter = vtk.vtkTransformPolyDataFilter()
-    transformFilter = SetInput(transformFilter, vtksource)
+    transformFilter.SetInputData(vtksource)
     transformFilter.SetTransform(trMat4x4)
     transformFilter = Update(transformFilter)
     coords = coordsFromVTK(transformFilter.GetOutput().GetPoints())
@@ -933,7 +882,7 @@ def _vtkCutter(self, vtkif):
     vtkobj = convert2VTU(self)
     cutter = vtk.vtkCutter()
     cutter.SetCutFunction(vtkif)
-    cutter = SetInput(cutter, vtkobj)
+    cutter.SetInputData(vtkobj)
     cutter = Update(cutter)
     cutter = cutter.GetOutput()
     [coords, cells, polys, lines, verts], fielddata, celldata, pointdata=convertFromVPD(cutter, samePlex=True)
@@ -982,7 +931,7 @@ def _vtkClipper(self, vtkif, insideout):
         vtkobj = convert2VTU(self)
 
     clipper = vtk.vtkClipDataSet()
-    clipper = SetInput(clipper, vtkobj)
+    clipper.SetInputData(vtkobj)
     clipper.SetClipFunction(vtkif)
     clipper.SetInsideOut(int(insideout))
     clipper = Update(clipper)
@@ -1242,10 +1191,6 @@ def vtkClip(self, implicitdata, method=None, insideout=False):
         raise ValueError('implicit object for cutting not well specified')
 
 
-
-# TODO
-# - verify against vmtkDistanceOfPoints
-# - add the multiprocessing option like vmtkDistanceOfPoints
 def distance(self, ref, normals=None, loctol=1e-3, normtol=1e-5, return_cellids=False):
     """Computes the distance of object from a reference object ref
 
@@ -1275,7 +1220,7 @@ def distance(self, ref, normals=None, loctol=1e-3, normtol=1e-5, return_cellids=
     else:
         normals=vtk.vtkPolyDataNormals()
         normals.ComputeCellNormalsOn()
-        normals=SetInput(normals, ref)
+        normals.SetInputData(ref)
         normals = Update(normals)
         normals = normals.GetOutput().GetCellData().GetNormals()
 
@@ -1350,7 +1295,7 @@ def meshQuality(self, measure):
     """
     vtkobj = convert2VTU(self)
     quality = vtk.vtkMeshQuality()
-    quality = SetInput(quality, vtkobj)
+    quality.SetInputData(vtkobj)
     elname = re.split("\d+", self.elName())[0].capitalize()
     if elname == 'Tri':
         elname ='Triangle'  # only exception
@@ -1447,7 +1392,7 @@ def delaunay2D(object, alpha=0.0, tol=0.001, offset = 1.25, bound_tri=False, con
     combinations of triangles, lines, and vertices.
     """
     chull = vtk.vtkDelaunay2D()
-    chull = SetInput(chull, convert2VPD(object))
+    chull.SetInputData(convert2VPD(object))
     chull.SetAlpha(alpha)
     chull.SetTolerance(tol)
     chull.SetOffset(offset)
@@ -1492,7 +1437,7 @@ def delaunay3D(object, alpha=0.0, tol=0.001, offset=2.5, bound_tri=False):
     """
 
     chull = vtk.vtkDelaunay3D()
-    chull = SetInput(chull, convert2VPD(object))
+    chull.SetInputData(convert2VPD(object))
     chull.SetAlpha(alpha)
     chull.SetTolerance(tol)
     chull.SetOffset(offset)
@@ -1507,6 +1452,9 @@ def delaunay3D(object, alpha=0.0, tol=0.001, offset=2.5, bound_tri=False):
         meshes.append(Mesh(coords, els, eltype=eltyps[els.shape[1]-1]))
     return meshes
 
+
+# TODO: check if this is needed. Can be replaced with
+#       Mesh.convert or TriSurface.remesh or TriSurface.coarsen
 def decimate(self, targetReduction=0.5, boundaryVertexDeletion=True):
     """Decimate a surface (both tri3 or quad4) and returns a trisurface
 
@@ -1514,7 +1462,6 @@ def decimate(self, targetReduction=0.5, boundaryVertexDeletion=True):
     - `targetReduction` : float (from 0.0 to 1.0) : desired number of triangles relative to input number of triangles
     - `boundaryVertexDeletion` : bool : if True it allows boundary point deletion
 
-    This function has been adapted from VMTK: vmtkScripts/vmtksurfacedecimation.py
     """
     from pyformex.trisurface import TriSurface
 
@@ -1523,7 +1470,7 @@ def decimate(self, targetReduction=0.5, boundaryVertexDeletion=True):
     vpd = cleanVPD(vpd)
 
     filter = vtk.vtkDecimatePro()
-    filter = SetInput(filter, vpd)
+    filter.SetInputData(vpd)
     filter.SetTargetReduction(targetReduction)
     filter.SetBoundaryVertexDeletion(boundaryVertexDeletion)
     filter.PreserveTopologyOn()
@@ -1550,7 +1497,7 @@ def coarsenPolyLine(self, target=0.5):
     vpd = convert2VPD(self, clean=True)  # convert pyFormex PolyLine to vpd
     vpd = cleanVPD(vpd)
     filter = vtk.vtkDecimatePolylineFilter()
-    filter = SetInput(filter, vpd)
+    filter.SetInputData(vpd)
     filter.SetTargetReduction(target)
 
     filter = Update(filter)
@@ -1651,7 +1598,6 @@ def install_trisurface_methods():
 
     """
     from pyformex import trisurface
-    trisurface.read_vtk_surface = read_vtk_surface
     trisurface.TriSurface.decimate = decimate
     trisurface.TriSurface.findElemContainingPoint = findElemContainingPoint
 
