@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2021 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 2.6  (Mon Aug 23 15:13:50 CEST 2021)
+##  This file is part of pyFormex 3.0  (Mon Nov 22 14:32:59 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -312,33 +312,15 @@ def save2zip(zipf, namedict):
     """
     from numpy.lib import format
 
-    if sys.version_info >= (3, 6):
-        # Since Python 3.6 it is possible to write directly to a ZIP file.
-        def write_text(val, fname, zipf):
-            force_zip64 = len(val) >= 2**30
-            with zipf.open(fname, 'w', force_zip64=force_zip64) as fil:
-                fil.write(val)
-
-        def write_array(val, fname, zipf):
-            force_zip64 = val.nbytes >= 2**30
-            with zipf.open(fname, 'w', force_zip64=force_zip64) as fil:
-                format.write_array(fil, val)
-    else:
-        # First write to a tempfile, then store tempfile in the zipf
-        def write_text(val, fname, zipf):
-            fil = utils.TempFile(prefix='pyformex-', suffix='.tmp')
+    def write_text(val, fname, zipf):
+        force_zip64 = len(val) >= 2**30
+        with zipf.open(fname, 'w', force_zip64=force_zip64) as fil:
             fil.write(val)
-            fil.flush()
-            zipf.write(fil.path, arcname=fname)
-            fil.close()
 
-        def write_array(val, fname, zipf):
-            fil = utils.TempFile(prefix='pyformex-', suffix='.tmp')
+    def write_array(val, fname, zipf):
+        force_zip64 = val.nbytes >= 2**30
+        with zipf.open(fname, 'w', force_zip64=force_zip64) as fil:
             format.write_array(fil, val)
-            fil.flush()
-            zipf.write(fil.path, arcname=fname)
-            fil.close()
-
 
     for key, val in namedict.items():
         if isinstance(val, str):
@@ -403,7 +385,7 @@ def savePZF(filename, **kargs):
     # Do not store camera if we store canvas
     if '_canvas' in kargs and '_camera' in kargs:
         del kargs['_camera']
-    pf.verbose(2, f"Saving {len(save_dict)} objects to PZF file")
+    pf.verbose(2, f"Saving {len(save_dict)} object attributes to PZF file")
     pf.verbose(2, f"Contents: {sorted(save_dict.keys())}")
     save_dict['__FORMAT'] = f"PZF {_pzf_version} (created by {pf.fullVersion()})\n"
     with zipfile.ZipFile(filename, 'w') as zip:
