@@ -2,7 +2,7 @@
 
 A modeless dialog with the same input items as dialog3
 """
-def create_array(nrows, ncols):
+def print_array(nrows, ncols):
     A = np.arange(nrows*ncols).reshape(nrows,ncols)
     print(A)
 
