@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2021 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 2.6  (Mon Aug 23 15:13:50 CEST 2021)
+##  This file is part of pyFormex 3.0  (Mon Nov 22 14:32:59 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -31,7 +31,6 @@ Formex structures representing simple geometric shapes.
 You need to import this module in your scripts to have access to its
 contents.
 """
-
 import numpy as np
 
 from pyformex import utils
@@ -110,27 +109,27 @@ def regularGrid(x0, x1, nx, swapaxes=None):
     Example:
 
     >>> regularGrid(0.,1.,4)
-    array([[ 0.  ],
-           [ 0.25],
-           [ 0.5 ],
-           [ 0.75],
-           [ 1.  ]])
+    array([[0.  ],
+           [0.25],
+           [0.5 ],
+           [0.75],
+           [1.  ]])
     >>> regularGrid((0.,0.),(1.,1.),(3,2))
-    array([[[ 0.  , 0.  ],
-            [ 0.33, 0.  ],
-            [ 0.67, 0.  ]],
+    array([[[0.  , 0.  ],
+            [0.33, 0.  ],
+            [0.67, 0.  ]],
     <BLANKLINE>
-           [[ 1.  , 0.  ],
-            [ 0.  , 0.5 ],
-            [ 0.33, 0.5 ]],
+           [[1.  , 0.  ],
+            [0.  , 0.5 ],
+            [0.33, 0.5 ]],
     <BLANKLINE>
-           [[ 0.67, 0.5 ],
-            [ 1.  , 0.5 ],
-            [ 0.  , 1.  ]],
+           [[0.67, 0.5 ],
+            [1.  , 0.5 ],
+            [0.  , 1.  ]],
     <BLANKLINE>
-           [[ 0.33, 1.  ],
-            [ 0.67, 1.  ],
-            [ 1.  , 1.  ]]])
+           [[0.33, 1.  ],
+            [0.67, 1.  ],
+            [1.  , 1.  ]]])
 
     """
     if swapaxes is None:
@@ -402,47 +401,100 @@ def quadraticCurve(x=None, n=8):
     return np.dot(H, x)
 
 
-def sphere(ndiv=6, base='icosa'):
-    """Create a triangulated approximation of a spherical surface.
+def sphere(ndiv=6, base='icosa', radius=1.0, equiv='R'):
+    """Create a triangulated surface approximating a sphere.
 
-    A (possibly high quality) approximation of a spherical surface is
-    constructed as follows. First a simple base triangulated surface
-    is created. Its triangular facets are subdivided by dividing all
-    edges in `ndiv` parts. The resulting mesh is then projected on a
-    sphere with unit radius. The higher `ndiv` is taken,
-    the better the approximation. For ``ndiv<=1``, the base surface is
-    returned.
+    The approximation of a spherical surface is constructed as follows.
+    First a simple base triangulated surface is created. Its triangular
+    facets are subdivided into identical smaller triangles by dividing
+    all edges in `ndiv` parts. The resulting mesh is then projected on a
+    sphere with the specified radius.
 
-    Parameters:
+    Parameters
+    ----------
+    ndiv: int
+        Number of divisions along the edges of the base surface. The higher
+        `ndiv` is taken, the better the approximation. With ``ndiv<=1``,
+        the base surface is returned.
+    base: str
+        The type of base surface to be used. Currently available:
 
-    - `ndiv`: number of divisions along the edges of the base surface.
-    - `base`: the type of base surface. One of the following:
+        - 'icosa': icosahedron (20 faces): this offers the highest
+          quality with triangles of almost same size and shape.
+        - 'octa': octahedron (8 faces): this model will have the same
+          mesh on each of the quadrants of the global axes.
+          The coordinate planes do not cut any triangle. This model is
+          this fit to be split along coordinate planes.
+    radius: float, optional
+        The radius of the sphere. Default is 1.0.
+    equiv: 'R' | 'A' | 'V'
+        The quantity that should be equivalent with the perfect sphere.
+        The default ('R') places the points exactly at the specified radius.
+        The computed area and volume will obviously be less than
+        those of the perfect sphere. With 'A' or 'V', the radius is
+        increased in such way that the triangular surface has the same
+        area, respectively volume, as the perfect sphere.
 
-      - 'icosa': icosahedron (20 faces): this offers the highest
-        quality with triangles of almost same size ans shape.
-      - 'octa': octahedron (8 faces): this model will have the same
-        mesh on each of the quadrants. The coordinate planes do not
-        cut any triangle. This model is this fit to be subdivided along
-        coordinate planes.
-
-    Returns a TriSurface, representing a triangulated approximation of a
-    spherical surface with radius 1 and center at the origin.
+    Returns
+    -------
+    TriSurface
+        A TriSurface representing a triangulated approximation of a
+        spherical surface with specified radius and center at the origin.
 
     Notes
     -----
     The number of elements is equal to 20*ndiv**2 for 'icosa' and
     8*ndiv**2 for 'octa'.
 
+    Examples
+    --------
+    This computes the relative area and volume of the triangulated
+    surface with respect to the perfect sphere
+
+    >>> for ndiv in range(1,9):
+    ...     S = sphere(ndiv)
+    ...     A = S.area() / (4*at.pi)
+    ...     V = S.volume() / (4/3*at.pi)
+    ...     np, nf = S.ncoords(), S.nelems()
+    ...     print(f"ndiv: {ndiv}; npoints: {np:3}; nfaces: {nf:4}; "
+    ...           f"area: {A:.4f}; volume: {V:.4f}")
+    ndiv: 1; npoints:  12; nfaces:   20; area: 0.7619; volume: 0.6055
+    ndiv: 2; npoints:  42; nfaces:   80; area: 0.9283; volume: 0.8735
+    ndiv: 3; npoints:  92; nfaces:  180; area: 0.9669; volume: 0.9409
+    ndiv: 4; npoints: 162; nfaces:  320; area: 0.9811; volume: 0.9662
+    ndiv: 5; npoints: 252; nfaces:  500; area: 0.9878; volume: 0.9781
+    ndiv: 6; npoints: 362; nfaces:  720; area: 0.9915; volume: 0.9848
+    ndiv: 7; npoints: 492; nfaces:  980; area: 0.9938; volume: 0.9888
+    ndiv: 8; npoints: 642; nfaces: 1280; area: 0.9952; volume: 0.9914
+
+    Here is a comparison of the radius, area and volume equivalent surfaces
+    for ``ndiv=4``.
+
+    >>> for equiv in ['R', 'A', 'V']:
+    ...     S = sphere(4, equiv=equiv)
+    ...     R = S.coords.distanceFromPoint([0.,0.,0.]).mean()
+    ...     A = S.area() / (4*at.pi)
+    ...     V = S.volume() / (4/3*at.pi)
+    ...     print(f"radius: {R:.4f}; area: {A:.4f}; volume: {V:.4f}")
+    radius: 1.0000; area: 0.9811; volume: 0.9662
+    radius: 1.0096; area: 1.0000; volume: 0.9942
+    radius: 1.0115; area: 1.0039; volume: 1.0000
     """
     from pyformex.elements import ElementType
     from pyformex.trisurface import TriSurface
 
     base = ElementType.get(base)
-    M = TriSurface(base.vertices, base.faces)
+    S = TriSurface(base.vertices, base.faces)
     if ndiv > 1:
-        M = M.subdivide(ndiv).fuse()
-    M = M.projectOnSphere()
-    return M
+        S = S.subdivide(ndiv).fuse()
+    S = S.projectOnSphere()
+    if equiv == 'A':
+        radius /= (S.area() / (4*at.pi)) ** 0.5
+    elif equiv == 'V':
+        radius /= (S.volume() / (4/3*at.pi)) ** (1/3)
+    if radius != 1.0:
+        S = S.scale(radius)
+    return S
 
 
 def MoebiusRing(nturns=1, nw=2, nl=30):
@@ -472,7 +524,7 @@ def MoebiusRing(nturns=1, nw=2, nl=30):
     strip = cell.replicm((nl, nw)).translate(1, -0.5*nw)
     a = nturns*180./nl
     torded = strip.map(lambda x, y, z: [x, y*at.cosd(x*a), y*at.sind(x*a)])
-    ring = torded.trl(2, nl/pi).scale([360./nl, 1., 1.]).trl(0, -90).cylindrical(dir=[2, 0, 1])
+    ring = torded.trl(2, nl/at.pi).scale([360./nl, 1., 1.]).trl(0, -90).cylindrical(dir=[2, 0, 1])
     return ring.toMesh()
 
 
