@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2021 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 2.6  (Mon Aug 23 15:13:50 CEST 2021)
+##  This file is part of pyFormex 3.0  (Mon Nov 22 14:32:59 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -90,15 +90,6 @@ class Software():
 
     The default software object only has two attributes:
 
-    Attributes
-    ----------
-    name: str
-        The registered name of the software.
-    version: str
-        The version of the software. This is set to None when the name is
-        registered, and becomes a (possibly empty) string after calling
-        the :meth:`detect` method.
-
     Examples
     --------
     >>> np = Software('numpy')
@@ -125,6 +116,16 @@ class Software():
     Traceback (most recent call last):
     ValueError: A Software with name 'foo' is already registered
     """
+    # REMOVED
+
+    # Attributes
+    # ----------
+    # name: str
+    #     The registered name of the software.
+    # version: str
+    #     The version of the software. This is set to None when the name is
+    #     registered, and becomes a (possibly empty) string after calling
+    #     the :meth:`detect` method.
 
     register = dict()
 
@@ -297,14 +298,15 @@ class Software():
                     realname = clas.register[name].name
                     errmsg = f"""..
 
-    **{clas.__name__} version {name} ({version}) does not meet requirements ({version})!**
+    **{clas.__name__} version {name} ({ver}) does not meet requirements ({version})!**
 
     You activated some functionality requiring {clas.__name__} '{realname}'.
     However, the required version for that software could not be found.
     """
                     pf.error(errmsg)
-                    raise ValueError(f"Required version of {clas.__name__} "
-                                     f"'{name}' ({realname}) not found")
+                    raise ValueError(
+                        f"Required version ({version}) of {clas.__name__} "
+                        f"'{name}' ({realname}) not found")
 
 
 
@@ -351,7 +353,7 @@ class Module(Software):
     >>> Module.print_all()
       numpy (** Not Found **)
       pil (** Not Found **)
-    >>> SaneVersion(Module.has('numpy')) >= SaneVersion('1.10')
+    >>> SaneVersion(Module.has('numpy')) >= SaneVersion('1.16')
     True
     >>> Module.print_all()
       numpy (1...)
@@ -378,7 +380,7 @@ class Module(Software):
     >>> Module.require('foo','>= 1.1.7')
     >>> Module.require('foo','>= 1.3.0')
     Traceback (most recent call last):
-    ValueError: Required version of Module 'foo' (FooBar) not found
+    ValueError: Required version (>= 1.3.0) of Module 'foo' (FooBar) not found
 
     """
 
@@ -460,21 +462,18 @@ Module('gnuplot', modname='Gnuplot')
 # Module('ipython', modname='IPython',)
 # Module('ipython-qt', modname='IPython.frontend.qt',)
 Module('matplotlib')
+Module('meshio')
+Module('moderngl')
 Module('numpy')
 Module('pil', modname='PIL')
 Module('pydicom')
 Module('pyopengl', modname='OpenGL')
-Module('meshio')
-Module('moderngl')
-Module('pyqt4', modname='PyQt4.QtCore', attr='QT_VERSION_STR')
-Module('pyqt4gl', modname='PyQt4.QtOpenGL', attr=('PyQt4.QtCore', 'QT_VERSION_STR'))
 Module('pyqt5', modname='PyQt5.QtCore', attr='PYQT_VERSION_STR')
 Module('pyqt5gl', modname='PyQt5.QtOpenGL', attr=('PyQt5.QtCore', 'PYQT_VERSION_STR'))
-Module('pyside', modname='PySide')
 Module('pyside2', modname='PySide2')
 Module('scipy')
 Module('sphinx')
-Module('vtk', modname='pyformex.vtk_light', attr='VTK_VERSION')
+Module('vtk', attr='VTK_VERSION')
 
 
 class External(Software):
@@ -586,7 +585,6 @@ External('recordmydesktop', 'recordmydesktop --version', r'recordMyDesktop v(\S+
 External('sphinx-build', "sphinx-build --version", r'sphinx-build (\S+)')
 External('tetgen', "bash -c 'type -p tetgen'", r'\S+(tetgen)')
 External('units', 'units --version', r'GNU Units version (\S+)')
-External('vmtk', "bash -c 'type -p vmtk'", r'(\S+)')
 
 
 def listLibraries():
@@ -846,12 +844,12 @@ if __name__ in ["_draw__", "__script__"]:
     Required = {
         'System': {
             'pyFormex_installtype': 'R',
-            'Python_version': '>= 3.6.0',
+            'Python_version': '>= 3.7.0',
         },
         'Modules': {
-            'pyformex': '>= 2.4',
+            'pyformex': '>= 2.7',
             'matplotlib': '1.1.1',
-            'numpy': '1.11',
+            'numpy': '1.16',
         },
         'Externals': {
             'admesh': '>= 0.95',
