@@ -3,7 +3,7 @@
 ##  SPDX-FileCopyrightText: © 2007-2021 Benedict Verhegghe <bverheg@gmail.com>
 ##  SPDX-License-Identifier: GPL-3.0-or-later
 ##
-##  This file is part of pyFormex 2.6  (Mon Aug 23 15:13:50 CEST 2021)
+##  This file is part of pyFormex 3.0  (Mon Nov 22 14:32:59 CET 2021)
 ##  pyFormex is a tool for generating, manipulating and transforming 3D
 ##  geometrical models by sequences of mathematical operations.
 ##  Home page: https://pyformex.org
@@ -37,7 +37,7 @@ Module attributes
 
 Attributes
 ----------
-FileTypes: OrderedDict
+FileTypes: dict
     A collection of :class:`FileType` records. Each FileType instance holds
     the definition of a file type, and is accessible from this dict with a
     simple mnemonic key. These are the ones that are commonly used in
@@ -65,7 +65,7 @@ off = 'Geomview object files (*.off)'
 pgf = 'pyFormex geometry files (*.pgf)'
 ply = 'Stanford Polygon File Format files (*.ply)'
 png = 'PNG images (*.png)'
-poly = 'Polygon/Line files (*.off *.obj *.ply)'
+poly = 'Polygon files (*.off *.obj *.ply)'
 postproc = 'Postproc scripts (*.post.py)'
 pyformex = 'pyFormex scripts (*.py *.pye)'
 pyf = 'pyFormex projects (*.pyf)'
@@ -74,7 +74,7 @@ pzf = 'pyFormex zip files (*.pzf)'
 smesh = 'Tetgen surface mesh files (*.smesh)'
 stl = 'STL files (*.stl)'
 stlb = 'Binary STL files (*.stl)'
-surface = 'Surface models (*.gts *.stl *.off *.obj)'
+surface = 'Surface models (*.gts *.stl *.off *.obj *.ply)'
 tetsurf = 'Tetgen surface (*.smesh)'
 tetgen = 'Tetgen files (*.poly *.smesh *.ele *.face *.edge *.node *.neigh)'
 video = 'Video (*.mp4)'
@@ -88,7 +88,7 @@ import re
 import tempfile
 import time
 import random
-from collections import OrderedDict
+import types
 
 import pyformex as pf
 from pyformex import Path
@@ -460,7 +460,7 @@ def matchAll(regexps, target):
 ## File types ##
 ################
 
-FileTypes = OrderedDict()
+FileTypes = {}
 
 
 class FileType:
@@ -599,7 +599,7 @@ FileType('off', 'Geomview object files', 'off')
 FileType('pgf', 'pyFormex geometry files', 'pgf')
 FileType('ply', 'Stanford Polygon File Format files', 'ply')
 FileType('png', 'PNG images', 'png')
-FileType('poly', 'Polygon/Line files', 'off', 'obj', 'ply')
+FileType('poly', 'Polygon files', 'off', 'obj', 'ply')
 FileType('postproc', 'Postproc scripts', 'post.py')
 FileType('pyformex', 'pyFormex scripts', 'py', 'pye')
 FileType('pyf', 'pyFormex projects', 'pyf')
@@ -608,7 +608,7 @@ FileType('pzf', 'pyFormex zip files', 'pzf')
 FileType('smesh', 'Tetgen surface mesh files', 'smesh')
 FileType('stl', 'STL files', 'stl')
 FileType('stlb', 'Binary STL files', 'stl')  # Use only for output
-FileType('surface', 'Surface models', 'gts', 'stl', 'off', 'obj')
+FileType('surface', 'Surface models', 'gts', 'stl', 'off', 'obj', 'ply')
 FileType('tetsurf', 'Tetgen surface', 'smesh')
 FileType('tetgen', 'Tetgen files', 'poly', 'smesh', 'ele', 'face',
          'edge', 'node', 'neigh')
@@ -897,10 +897,6 @@ def sourceFiles(relative=False, symlinks=True, extended=False):
         includefiles=['.*[.]py$', 'pyformexrc'],
         excludefiles=['[.].*'],  # exclude hidden files, like autobackups
         symlinks=symlinks)
-    # Add the one file from vtk_light that is really pyFormex source
-    onemore = path / "vtk_light" / "__init__.py"
-    if onemore.exists():
-        files.append(onemore.relative_to(Path.cwd()))
     if extended:
         searchdirs = [Path(i[1]) for i in pf.cfg['appdirs'] + pf.cfg['scriptdirs']]
         for path in set(searchdirs):
@@ -1097,10 +1093,11 @@ class TempDir(tempfile.TemporaryDirectory):
     - the context manager automatically changes back to the original workdir
 
     """
-    def __init__(self, suffix=None, prefix='pyf_', dir=None, chdir=False):
+    def __init__(self, suffix=None, prefix='pyf_', dir=None, chdir=False, keep=False):
         super().__init__(suffix, prefix, dir)
         self.prev = os.getcwd()
         self.chdir = chdir
+        self.keep = keep
 
     @property
     def path(self):
@@ -1113,7 +1110,8 @@ class TempDir(tempfile.TemporaryDirectory):
 
     def __exit__(self, *args):
         os.chdir(self.prev)
-        super().__exit__(*args)
+        if not self.keep:
+            super().__exit__(*args)
 
 
 def TempFile(*args, **kargs):
@@ -1382,75 +1380,162 @@ def convertText(text, format=''):
 def forceReST(text, underline=False):
     """Convert a text string to have it recognized as reStructuredText.
 
-    Returns the text with two lines prepended: a line with '..'
-    and a blank line. The text display functions will then recognize the
-    string as being reStructuredText. Since the '..' starts a comment in
-    reStructuredText, it will not be displayed.
+    Parameters
+    ----------
+    text: str
+        A multiline string with some text that is formated as
+        reStructuredText.
+    underline: bool
+        If True, the first line of the text will be underlined to make
+        it a header in the reStructuredText.
+
+    Returns
+    -------
+    str:
+        The input text with two lines prepended: a line with '..'
+        and a blank line. The pyFormex text display functions will then
+        recognize the text as being reStructuredText.
+        Since the '..' starts a comment in reStructuredText, the extra
+        lines are not displayed. If underline=True, an extra line is
+        added below the (original) first line, to make that line appear
+        as a header.
+
+    Examples
+    --------
+    >>> print(forceReST('Header\\nBody', underline=True))
+    ..
+    <BLANKLINE>
+    Header
+    ------
+    Body
 
-    Furthermore, if `underline` is set True, the first line of the text
-    will be underlined to make it appear as a header.
     """
     if underline:
         text = underlineHeader(text)
     return "..\n\n" + text
 
 
-def underlineHeader(s, char='-'):
+def underlineHeader(s, c='-'):
     """Underline the first line of a text.
 
-    Adds a new line of text below the first line of s. The new line
-    has the same length as the first, but all characters are equal to
-    the specified char.
+    Parameters
+    ----------
+    s: str
+        A multiline string.
+    c: char, optional
+        The character to use for underlining. Default is '-'.
+
+    Returns
+    -------
+    str:
+        A multiline string with the original text plus an extra line
+        inserted below the first line. The new line has the same length
+        as the first, but all characters are equal to the specified char.
 
     >>> print(underlineHeader("Hello World"))
     Hello World
     -----------
-
     """
     i = s.find('\n')
     if i < 0:
         i = len(s)
-    return s[:i] + '\n' + char*i + s[i:]
+    return s[:i] + '\n' + c*i + s[i:]
 
 
-def framedText(text, padding=[0, 2, 0, 2], border=[1, 2, 1, 2], margin=[0, 0, 0, 0],
-               borderchar='####', cornerchar=None, width=None, adjust='l'):
+def sameLength(lines, length=-1, adjust='l'):
+    """Make a sequence of strings the same length.
+
+    Parameters
+    ----------
+    lines: list of str
+        A sequence of single line strings.
+    length: int
+        The required length of the lines. If negative, the length is
+        set to the maximum input line length.
+    adjust: 'l' | 'c' | 'r'
+        How the input lines are adjusted to respectively the left,
+        the center or the right of the total length of the line.
+
+    Examples
+    --------
+    >>> sameLength(['a', 'bb', 'ccc'])
+    ['a  ', 'bb ', 'ccc']
+    >>> sameLength(['a', 'bb', 'ccc'], adjust='c')
+    [' a ', ' bb', 'ccc']
+    >>> sameLength(['a', 'bb', 'ccc'], adjust='r')
+    ['  a', ' bb', 'ccc']
+    >>> sameLength(['a', 'bb', 'ccc'], length=2)
+    ['a ', 'bb', 'cc']
+    """
+    if length < 0:
+        length = max([len(l) for l in lines])
+    _adjust = {'c': str.center, 'l':str.ljust, 'r':str.rjust}[adjust]
+    return [_adjust(line, length) if len(line) <= length else line[:length]
+            for line in lines]
+
+
+def framedText(text,
+               padding=[0, 2, 0, 2], border=[1, 2, 1, 2], margin=[0, 0, 0, 0],
+               borderchar='####', adjust='l'):
     """Create a text with a frame around it.
 
-    - `adjust`: 'l', 'c' or 'r': makes the text lines be adjusted to the
-      left, center or right.
+    Parameters
+    ----------
+    padding: list of int
+        Number of blank spaces around text, at the top, right, bottom, left.
+    border: list of int
+        Border width, at the top, right, bottom, left.
+    margin: list of int
+        Number of blank spaces around border, at the top, right, bottom, left.
+    borderchar: str
+        Border charater, at the top, right, bottom, left.
+    width: int
+        Intended width of the
+    adjust: 'l' | 'c' | 'r'
+        Adjust the text to the left, center or right.
 
+    Returns
+    -------
+    str:
+        A multiline string with the formatted framed text.
+
+    Examples
+    --------
     >>> print(framedText("Hello World,\\nThis is me calling",adjust='c'))
     ##########################
     ##     Hello World,     ##
     ##  This is me calling  ##
     ##########################
-
+    >>> print(framedText("Hello World,\\nThis is me calling",margin=[1,0,0,3]))
+    <BLANKLINE>
+       ##########################
+       ##  Hello World,        ##
+       ##  This is me calling  ##
+       ##########################
     """
     lines = text.splitlines()
     maxlen = max([len(l) for l in lines])
-    if adjust == 'c':
-        lines = [l.center(maxlen) for l in lines]
-    elif adjust == 'r':
-        lines = [l.rjust(maxlen) for l in lines]
-    else:
-        lines = [l.ljust(maxlen) for l in lines]
-    prefix = ' '*margin[3] + borderchar[3]*border[3] + ' '*padding[3]
-    suffix = ' '*padding[1] + borderchar[1]*border[1] + ' '*margin[1]
-    width = len(prefix)+maxlen+len(suffix)
+    lines = sameLength(lines, maxlen)
+    prefix = borderchar[3]*border[3] + ' '*padding[3]
+    suffix = ' '*padding[1] + borderchar[1]*border[1]
+    width = len(prefix) + maxlen + len(suffix)
+    lmargin = ' '*margin[3]
+    prefix = lmargin + prefix
+    paddingline = prefix + ' '*maxlen + suffix
+    borderline = lmargin + borderchar[0]*width
     s = []
     for i in range(margin[0]):
         s.append('')
     for i in range(border[0]):
-        s.append(borderchar[0]*width)
+        s.append(borderline)
     for i in range(padding[0]):
-        s.append(prefix+' '*maxlen+suffix)
+        s.append(paddingline)
     for l in lines:
-        s.append(prefix+("%"+str(maxlen)+"s") % l+suffix)
+        s.append(prefix + l + suffix)
     for i in range(padding[2]):
-        s.append(prefix+' '*maxlen+suffix)
+        s.append(paddingline)
     for i in range(border[2]):
-        s.append(borderchar[2]*width)
+        s.append(borderline)
     for i in range(margin[2]):
         s.append('')
     return '\n'.join(s)
@@ -1459,9 +1544,20 @@ def framedText(text, padding=[0, 2, 0, 2], border=[1, 2, 1, 2], margin=[0, 0, 0,
 def prefixText(text, prefix):
     """Add a prefix to all lines of a text.
 
-    - `text`: multiline string
-    - `prefix`: string: prefix to insert at the start of all lines of text.
+    Parameters
+    ----------
+    text: str
+        A multiline string with the input text.
+    prefix: str
+        A string to be inserted at the start of all lines of text.
 
+    Returns
+    -------
+    str
+        A multiline string with the input lines prefixed with prefix.
+
+    Examples
+    --------
     >>> print(prefixText("line1\\nline2","** "))
     ** line1
     ** line2
@@ -2121,7 +2217,6 @@ def globFiles(pattern, sort=hsorted):
 
 _autoname = {}
 
-
 def autoName(clas):
     """Return the autoname class instance for objects of type clas.
 
@@ -2499,10 +2594,6 @@ def defaultMonoFont():
     return fonts[0]
 
 
-@deprecated_by('utils.listAllFonts','utils.listFonts')
-def listAllFonts():
-    return listFonts()
-
 def listMonoFonts():
     """List only the monospace fonts
 
@@ -2513,6 +2604,53 @@ def listMonoFonts():
     return listFonts(mono=True)
 
 
+#######################################################
+##  Namespace  ##
+#################
+
+class Namespace(types.SimpleNamespace):
+    """A SimpleNamespace subclass that also has dict access methods.
+
+    The NameSpace class adds three dunder methods to the
+    :class:`types.SimpleNamespace` class:
+    __getitem__, __setitem__ and__delitem__.
+    This allows the attributes also to be accessed with dict methods.
+    Furthermore, it defines an _attrs method to get a list of the
+    defined attributes.
+
+    Examples
+    --------
+    >>> S = Namespace(a=0, b=1)
+    >>> print(S)
+    Namespace(a=0, b=1)
+    >>> S['c'] = 2
+    >>> S.a = 3
+    >>> print(S)
+    Namespace(a=3, b=1, c=2)
+    >>> print(S.a, S['a'])
+    3 3
+    >>> del S.a
+    >>> T = Namespace(**{'b':1, 'c':2})
+    >>> print(S, T)
+    Namespace(b=1, c=2) Namespace(b=1, c=2)
+    >>> print(S == T)
+    True
+    >>> del S['c']
+    >>> print(S == T)
+    False
+    >>> print(T._attrs())
+    ['b', 'c']
+    """
+    def __getitem__(self, k):
+        return self.__getattribute__(k)
+    def __setitem__(self, k, v):
+        self.__setattr__(k,v)
+    def __delitem__(self, k):
+        self.__delattr__(k)
+    def _attrs(self):
+        return list(self.__dict__)
+
+
 ###########################################################################
 
 
@@ -2523,7 +2661,7 @@ def execFile(f, *args, **kargs):
 
 def interrogate(item):
     """Print useful information about item."""
-    info = OrderedDict()
+    info = {}
     if hasattr(item, '__name__'):
         info["NAME:    "] = item.__name__
     if hasattr(item, '__class__'):
@@ -2650,6 +2788,9 @@ def memUsed():
 
 is_pyFormex = is_script
 
+@deprecated_by('utils.listAllFonts','utils.listFonts')
+def listAllFonts():
+    return listFonts()
 
 @deprecated_by('utils.runCommand', 'utils.command')
 def runCommand(cmd, timeout=None, shell=True, **kargs):
